#!/bin/sh

# BEGIN DESCRIPTION
# SYNOPSYS
#     $program [DIR]
#
# DESCRIPTION
#     This program patches hscpipe 8.x so that it will be able to process
#     new narrow band filters.
#
#     If hscpipe 8.x has been set up (or to be specific, if \$OBS_SUBARU_DIR
#     has been set), DIR can be omitted.
#     If DIR is specified, it must be the path to hscpipe 8.x. For example,
#
#         $program /opt/hscpipe/8.4
# END DESCRIPTION

if [ "$1" = "-h" ] || [ "$1" = "--help" ]
then
    program=$(basename "$0")
    eval echo \""$(
        sed -n -e '/^# BEGIN DESCRIPTION/,/^# END DESCRIPTION/{s/^\(# \|#\)//;p}' "$0" |
        sed -n -e '1d;$d;p'
    )"\"

    exit 0
fi

if [ "$#" -eq 0 ] && [ -z "$OBS_SUBARU_DIR" ]
then
    echo "Please setup hscpipe 8.x first,"
    echo "or specify where hscpipe 8.x has been installed."
    echo ""
    echo "See --help."
    exit 1
fi

if [ "$#" -gt 1 ]
then
    shift
    echo "error: Unrecognized arguments:" "$@"
    echo ""
    echo "See --help."
    exit 1
fi

if [ "$#" -eq 1 ]
then
    echo "Searching $1 for 'obs_subaru' installation ..."
    found="$(find "$1" -path "*/obs_subaru" -exec find "{}" -type d -name "python" ";")"

    if [ -z "$found" ]
    then
        echo "error: Directory 'obs_subaru' is not found."
        exit 1
    fi
    if [ "$(echo "$found" | wc -l)" -ne 1 ]
    then
        echo "error: More than one 'obs_subaru' installation are found:"
        echo "$found"
        exit 1
    fi

    OBS_SUBARU_DIR="$(dirname "$found")"
    echo "Found OBS_SUBARU_DIR=$OBS_SUBARU_DIR"
fi

if ! cd "$OBS_SUBARU_DIR"
then
    echo "error: Cannot change directory to: \$OBS_SUBARU_DIR=$OBS_SUBARU_DIR"
    exit 1
fi

checksum="$(cksum config/hsc/colorterms.py)"
version=0

if [ "$checksum" = "778888616 8985 config/hsc/colorterms.py" ]
then
    # Not patched
    version=0
elif [ "$checksum" = "2532695348 9551 config/hsc/colorterms.py" ]
then
    # Patch v1 has been applied
    version=1
elif [ "$checksum" = "2732775515 9937 config/hsc/colorterms.py" ]
then
    # Patch v2 has been applied
    version=2
elif [ "$checksum" = "2971925197 10324 config/hsc/colorterms.py" ]
then
    if [ "$(cksum python/lsst/obs/hsc/makeTransmissionCurves.py)" = "4229697431 6680 python/lsst/obs/hsc/makeTransmissionCurves.py" ]
    then
        # Patch v3 has been applied
        version=3
    else
        # Patch v4 has been applied
        version=4
    fi
else
    echo "warning: File checksum indicates $OBS_SUBARU_DIR has already been modified."
    echo "Applying patches to this directory may mess it up. Proceed anyway?"
    answer="n"
    read -p "[y/N]" answer
    if [ -z "$(echo "$answer" | grep '^y')" ]
    then
        echo "Canceled."
        exit 1
    fi
fi

echo "Applying patches to $OBS_SUBARU_DIR..."

if [ $version -le 0 ]
then
patch -p7 << "__eof__"
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-02-16 21:06:02.218247985 +0900
@@ -74,7 +74,10 @@
         'y': Colorterm(primary="y", secondary="z", c0=-0.002055, c1=0.209680, c2=0.227296),
         'I945': Colorterm(primary="y", secondary="z", c0=0.005275, c1=-0.194285, c2=-0.125424),
         'N387': Colorterm(primary="g", secondary="r", c0=0.427879, c1=1.869068, c2=0.540580),
+        'N391': Colorterm(primary="g", secondary="r",c0=0.386888, c1=1.688354, c2=0.525252),
+        'N395': Colorterm(primary="g", secondary="r", c0=0.326378, c1=1.477711, c2=0.483298),
         'N400': Colorterm(primary="g", secondary="r", c0=0.176542, c1=1.127055, c2=0.505502),
+        'N430': Colorterm(primary="g", secondary="r",c0=0.121335, c1=0.809929, c2=0.126250),
         'N468': Colorterm(primary="g", secondary="r", c0=-0.042240, c1=0.121756, c2=0.027599),
         'N515': Colorterm(primary="g", secondary="r", c0=-0.021913, c1=-0.253159, c2=0.151553),
         'N527': Colorterm(primary="g", secondary="r", c0=-0.020641, c1=-0.366167, c2=0.038497),
@@ -96,7 +99,10 @@
         'HSC-Y': Colorterm(primary="y", secondary="z", c0=-0.002055, c1=0.209680, c2=0.227296),
         'IB0945': Colorterm(primary="y", secondary="z", c0=0.005275, c1=-0.194285, c2=-0.125424),
         'NB0387': Colorterm(primary="g", secondary="r", c0=0.427879, c1=1.869068, c2=0.540580),
+        'NB0391': Colorterm(primary="g", secondary="r",c0=0.386888, c1=1.688354, c2=0.525252),
+        'NB0395': Colorterm(primary="g", secondary="r", c0=0.326378, c1=1.477711, c2=0.483298),
         'NB0400': Colorterm(primary="g", secondary="r", c0=0.176542, c1=1.127055, c2=0.505502),
+        'NB0430': Colorterm(primary="g", secondary="r",c0=0.121335, c1=0.809929, c2=0.126250),
         'NB0468': Colorterm(primary="g", secondary="r", c0=-0.042240, c1=0.121756, c2=0.027599),
         'NB0515': Colorterm(primary="g", secondary="r", c0=-0.021913, c1=-0.253159, c2=0.151553),
         'NB0527': Colorterm(primary="g", secondary="r", c0=-0.020641, c1=-0.366167, c2=0.038497),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-02-16 21:06:02.218247985 +0900
@@ -5,7 +5,12 @@
         ("i2", "i"),
         # Narrow bands
         ('N387', 'g'),
+        ('N391', 'g'),
+        ('N395', 'g'),
+        ('N400', 'g'),
+        ('N430', 'g'),
         ('N468', 'g'),
+        ('N497', 'g'),
         ('N515', 'g'),
         ('N527', 'g'),
         ('N656', 'r'),
@@ -30,7 +35,11 @@
         ("HSC-Y", "y"),
         # Narrow bands
         ('NB0387', 'g'),
+        ('NB0391', 'g'),
+        ('NB0395', 'g'),
+        ('NB0430', 'g'),
         ('NB0468', 'g'),
+        ('NB0497', 'g'),
         ('NB0515', 'g'),
         ('NB0527', 'g'),
         ('NB0656', 'r'),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB391.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB391.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB391.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB391.txt	2023-02-16 21:06:02.218247985 +0900
@@ -0,0 +1,100 @@
+# wavelength[angstrom]  transmittance
+3701.5  0.0098
+3705.5  0.0094
+3709.6  0.0088
+3713.6  0.0080
+3717.6  0.0071
+3721.6  0.0073
+3725.7  0.0073
+3729.7  0.0073
+3733.7  0.0077
+3737.8  0.0079
+3741.8  0.0071
+3745.8  0.0062
+3749.9  0.0057
+3753.9  0.0058
+3757.9  0.0059
+3762.0  0.0058
+3766.0  0.0057
+3770.0  0.0053
+3774.1  0.0051
+3778.1  0.0049
+3782.1  0.0049
+3786.2  0.0049
+3790.2  0.0048
+3794.2  0.0048
+3798.3  0.0050
+3802.3  0.0050
+3806.4  0.0050
+3810.4  0.0048
+3814.4  0.0048
+3818.5  0.0051
+3822.5  0.0055
+3826.6  0.0060
+3830.6  0.0066
+3834.7  0.0074
+3838.7  0.0090
+3842.7  0.0125
+3846.8  0.0200
+3850.8  0.0352
+3854.9  0.0627
+3858.9  0.1072
+3863.0  0.1709
+3867.0  0.2519
+3871.1  0.3463
+3875.1  0.4447
+3879.2  0.5384
+3883.2  0.6191
+3887.2  0.6831
+3891.3  0.7292
+3895.3  0.7571
+3899.4  0.7684
+3903.4  0.7729
+3907.5  0.7774
+3911.5  0.7843
+3915.6  0.7905
+3919.7  0.7880
+3923.7  0.7834
+3927.8  0.7781
+3931.8  0.7751
+3935.9  0.7802
+3939.9  0.7783
+3944.0  0.7540
+3948.0  0.7166
+3952.1  0.6667
+3956.1  0.5976
+3960.2  0.5155
+3964.3  0.4294
+3968.3  0.3383
+3972.4  0.2485
+3976.4  0.1703
+3980.5  0.1091
+3984.6  0.0655
+3988.6  0.0376
+3992.7  0.0213
+3996.7  0.0122
+4000.8  0.0072
+4004.9  0.0045
+4008.9  0.0032
+4013.0  0.0025
+4017.1  0.0021
+4021.1  0.0017
+4025.2  0.0015
+4029.2  0.0014
+4033.3  0.0013
+4037.4  0.0013
+4041.4  0.0013
+4045.5  0.0014
+4049.6  0.0014
+4053.6  0.0012
+4057.7  0.0011
+4061.8  0.0012
+4065.9  0.0013
+4069.9  0.0012
+4074.0  0.0011
+4078.1  0.0011
+4082.1  0.0011
+4086.2  0.0011
+4090.3  0.0011
+4094.4  0.0012
+4098.4  0.0011
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB395.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB395.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB395.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB395.txt	2023-02-16 21:06:02.218247985 +0900
@@ -0,0 +1,124 @@
+# wavelength[angstrom]  transmittance
+3701.5  0.0126
+3705.5  0.0115
+3709.6  0.0099
+3713.6  0.0109
+3717.6  0.0111
+3721.6  0.0091
+3725.7  0.0095
+3729.7  0.0094
+3733.7  0.0082
+3737.8  0.0084
+3741.8  0.0074
+3745.8  0.0069
+3749.9  0.0068
+3753.9  0.0064
+3757.9  0.0068
+3762.0  0.0062
+3766.0  0.0061
+3770.0  0.0062
+3774.1  0.0059
+3778.1  0.0055
+3782.1  0.0052
+3786.2  0.0050
+3790.2  0.0046
+3794.2  0.0047
+3798.3  0.0050
+3802.3  0.0047
+3806.4  0.0042
+3810.4  0.0041
+3814.4  0.0039
+3818.5  0.0042
+3822.5  0.0041
+3826.6  0.0043
+3830.6  0.0040
+3834.7  0.0043
+3838.7  0.0051
+3842.7  0.0057
+3846.8  0.0069
+3850.8  0.0086
+3854.9  0.0102
+3858.9  0.0118
+3863.0  0.0152
+3867.0  0.0206
+3871.1  0.0285
+3875.1  0.0412
+3879.2  0.0618
+3883.2  0.0917
+3887.2  0.1298
+3891.3  0.1763
+3895.3  0.2362
+3899.4  0.3098
+3903.4  0.3891
+3907.5  0.4675
+3911.5  0.5408
+3915.6  0.6086
+3919.7  0.6774
+3923.7  0.7302
+3927.8  0.7566
+3931.8  0.7669
+3935.9  0.7770
+3939.9  0.7969
+3944.0  0.8211
+3948.0  0.8302
+3952.1  0.8291
+3956.1  0.8416
+3960.2  0.8613
+3964.3  0.8634
+3968.3  0.8460
+3972.4  0.8293
+3976.4  0.8079
+3980.5  0.7619
+3984.6  0.7061
+3988.6  0.6459
+3992.7  0.5760
+3996.7  0.5019
+4000.8  0.4272
+4004.9  0.3571
+4008.9  0.2929
+4013.0  0.2374
+4017.1  0.1936
+4021.1  0.1583
+4025.2  0.1293
+4029.2  0.1032
+4033.3  0.0779
+4037.4  0.0551
+4041.4  0.0369
+4045.5  0.0241
+4049.6  0.0163
+4053.6  0.0121
+4057.7  0.0098
+4061.8  0.0085
+4065.9  0.0074
+4069.9  0.0062
+4074.0  0.0050
+4078.1  0.0039
+4082.1  0.0033
+4086.2  0.0028
+4090.3  0.0027
+4094.4  0.0026
+4098.4  0.0025
+4102.5  0.0024
+4106.6  0.0024
+4110.6  0.0024
+4114.7  0.0024
+4118.8  0.0024
+4122.9  0.0026
+4127.0  0.0025
+4131.0  0.0023
+4135.1  0.0023
+4139.2  0.0026
+4143.3  0.0027
+4147.3  0.0024
+4151.4  0.0025
+4155.5  0.0027
+4159.6  0.0025
+4163.7  0.0025
+4167.7  0.0024
+4171.8  0.0025
+4175.9  0.0026
+4180.0  0.0025
+4184.1  0.0025
+4188.2  0.0028
+4192.2  0.0028
+4196.3  0.0027
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB430.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB430.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB430.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB430.txt	2023-02-16 21:06:02.219248009 +0900
@@ -0,0 +1,99 @@
+# wavelength[angstrom]  transmittance
+4102.5  0.0100
+4106.6  0.0102
+4110.6  0.0099
+4114.7  0.0110
+4118.8  0.0104
+4122.9  0.0106
+4127.0  0.0102
+4131.0  0.0104
+4135.1  0.0105
+4139.2  0.0106
+4143.3  0.0108
+4147.3  0.0095
+4151.4  0.0105
+4155.5  0.0107
+4159.6  0.0103
+4163.7  0.0100
+4167.7  0.0095
+4171.8  0.0098
+4175.9  0.0098
+4180.0  0.0102
+4184.1  0.0103
+4188.2  0.0113
+4192.2  0.0096
+4196.3  0.0097
+4200.4  0.0096
+4204.5  0.0094
+4208.6  0.0100
+4212.7  0.0087
+4216.7  0.0097
+4220.8  0.0098
+4224.9  0.0088
+4229.0  0.0089
+4233.1  0.0095
+4237.2  0.0096
+4241.3  0.0096
+4245.4  0.0097
+4249.5  0.0100
+4253.5  0.0119
+4257.6  0.0168
+4261.7  0.0317
+4265.8  0.0666
+4269.9  0.1363
+4274.0  0.2473
+4278.1  0.3879
+4282.2  0.5396
+4286.3  0.6884
+4290.4  0.8202
+4294.5  0.9139
+4298.6  0.9603
+4302.7  0.9672
+4306.8  0.9655
+4310.9  0.9536
+4315.0  0.9070
+4319.1  0.8219
+4323.2  0.7004
+4327.3  0.5527
+4331.4  0.3943
+4335.5  0.2431
+4339.6  0.1265
+4343.7  0.0578
+4347.8  0.0260
+4351.9  0.0139
+4356.0  0.0101
+4360.1  0.0092
+4364.2  0.0085
+4368.3  0.0077
+4372.4  0.0076
+4376.5  0.0073
+4380.6  0.0077
+4384.7  0.0064
+4388.8  0.0070
+4392.9  0.0073
+4397.0  0.0064
+4401.1  0.0072
+4405.2  0.0060
+4409.3  0.0065
+4413.4  0.0067
+4417.6  0.0074
+4421.7  0.0071
+4425.8  0.0073
+4429.9  0.0062
+4434.0  0.0063
+4438.1  0.0067
+4442.2  0.0061
+4446.3  0.0063
+4450.4  0.0067
+4454.6  0.0067
+4458.7  0.0063
+4462.8  0.0057
+4466.9  0.0052
+4471.0  0.0061
+4475.1  0.0057
+4479.2  0.0064
+4483.4  0.0063
+4487.5  0.0059
+4491.6  0.0064
+4495.7  0.0061
+4499.8  0.0048
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB497.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB497.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB497.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB497.txt	2023-02-16 21:06:02.219248009 +0900
@@ -0,0 +1,61 @@
+# wavelength[angstrom] transmittance
+4851.5 0.0024
+4855.7 0.0022
+4859.8 0.0027
+4864.0 0.0024
+4868.1 0.0024
+4872.3 0.0024
+4876.5 0.0028
+4880.6 0.0032
+4884.8 0.0031
+4888.9 0.0049
+4893.1 0.0085
+4897.3 0.0141
+4901.4 0.0234
+4905.6 0.0396
+4909.8 0.0683
+4913.9 0.1177
+4918.1 0.1941
+4922.2 0.2935
+4926.4 0.4057
+4930.6 0.5222
+4934.7 0.6337
+4938.9 0.7351
+4943.1 0.8169
+4947.2 0.8675
+4951.4 0.8887
+4955.6 0.8953
+4959.7 0.9025
+4963.9 0.9132
+4968.1 0.9200
+4972.2 0.9175
+4976.4 0.8852
+4980.6 0.8181
+4984.8 0.7415
+4988.9 0.6492
+4993.1 0.5380
+4997.3 0.4153
+5001.4 0.2892
+5005.6 0.1783
+5009.8 0.1007
+5014.0 0.0558
+5018.1 0.0320
+5022.3 0.0196
+5026.5 0.0123
+5030.7 0.0080
+5034.8 0.0053
+5039.0 0.0035
+5043.2 0.0028
+5047.4 0.0024
+5051.5 0.0024
+5055.7 0.0021
+5059.9 0.0021
+5064.1 0.0020
+5068.3 0.0020
+5072.4 0.0020
+5076.6 0.0019
+5080.8 0.0019
+5085.0 0.0020
+5089.2 0.0019
+5093.3 0.0018
+5097.5 0.0019
__eof__
fi

if [ $version -le 1 ]
then
patch -p7 << "__eof__"
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-02-16 21:06:02.218247985 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-02-16 21:06:19.305658943 +0900
@@ -29,6 +29,7 @@
         'y': Colorterm(primary="z", secondary="i", c0=0.003386, c1=0.428877, c2=0.076738),
         'I945': Colorterm(primary="z", secondary="i", c0=0.008117, c1=0.234991, c2=-0.042255),
         'N387': Colorterm(primary="u", secondary="g", c0=-0.709229, c1=0.310719, c2=-0.044107),
+        'N395': Colorterm(primary="u", secondary="g", c0=-0.484711, c1=-0.095468, c2=0.002404),
         'N400': Colorterm(primary="u", secondary="g", c0=-0.396264, c1=-0.395133, c2=0.038688),
         'N468': Colorterm(primary="g", secondary="r", c0=-0.059159, c1=-0.030881, c2=0.015356),
         'N515': Colorterm(primary="g", secondary="r", c0=-0.032510, c1=-0.354440, c2=0.100832),
@@ -51,6 +52,7 @@
         'HSC-y': Colorterm(primary="z", secondary="i", c0=0.003386, c1=0.428877, c2=0.076738),
         'IB0945': Colorterm(primary="z", secondary="i", c0=0.008117, c1=0.234991, c2=-0.042255),
         'NB0387': Colorterm(primary="u", secondary="g", c0=-0.709229, c1=0.310719, c2=-0.044107),
+        'NB0395': Colorterm(primary="u", secondary="g", c0=-0.484711, c1=-0.095468, c2=0.002404),
         'NB0400': Colorterm(primary="u", secondary="g", c0=-0.396264, c1=-0.395133, c2=0.038688),
         'NB0468': Colorterm(primary="g", secondary="r", c0=-0.059159, c1=-0.030881, c2=0.015356),
         'NB0515': Colorterm(primary="g", secondary="r", c0=-0.032510, c1=-0.354440, c2=0.100832),
@@ -79,6 +81,7 @@
         'N400': Colorterm(primary="g", secondary="r", c0=0.176542, c1=1.127055, c2=0.505502),
         'N430': Colorterm(primary="g", secondary="r",c0=0.121335, c1=0.809929, c2=0.126250),
         'N468': Colorterm(primary="g", secondary="r", c0=-0.042240, c1=0.121756, c2=0.027599),
+        'N497': Colorterm(primary="g", secondary="r",c0=-0.044134, c1=-0.168663, c2=0.052961),
         'N515': Colorterm(primary="g", secondary="r", c0=-0.021913, c1=-0.253159, c2=0.151553),
         'N527': Colorterm(primary="g", secondary="r", c0=-0.020641, c1=-0.366167, c2=0.038497),
         'N656': Colorterm(primary="r", secondary="i", c0=0.035655, c1=-0.512046, c2=0.042796),
@@ -104,6 +107,7 @@
         'NB0400': Colorterm(primary="g", secondary="r", c0=0.176542, c1=1.127055, c2=0.505502),
         'NB0430': Colorterm(primary="g", secondary="r",c0=0.121335, c1=0.809929, c2=0.126250),
         'NB0468': Colorterm(primary="g", secondary="r", c0=-0.042240, c1=0.121756, c2=0.027599),
+        'NB0497': Colorterm(primary="g", secondary="r",c0=-0.044134, c1=-0.168663, c2=0.052961),
         'NB0515': Colorterm(primary="g", secondary="r", c0=-0.021913, c1=-0.253159, c2=0.151553),
         'NB0527': Colorterm(primary="g", secondary="r", c0=-0.020641, c1=-0.366167, c2=0.038497),
         'NB0656': Colorterm(primary="r", secondary="i", c0=0.035655, c1=-0.512046, c2=0.042796),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py	2023-02-16 21:06:19.305658943 +0900
@@ -3,12 +3,26 @@
 #
 # Band, A_filter/E(B-V)
 config.extinctionCoeffs = {
-    "HSC-G": 3.240,
-    "HSC-R": 2.276,
-    "HSC-I": 1.633,
-    "HSC-Z": 1.263,
-    "HSC-Y": 1.075,
+    "HSC-G": 3.238,
+    "HSC-R": 2.277,
+    "HSC-I": 1.617,
+    "HSC-Z": 1.261,
+    "HSC-Y": 1.074,
     "NB0387": 4.007,
+    "NB0391": 3.960,
+    "NB0395": 3.929,
+    "NB0400": 3.891,
+    "NB0430": 3.661,
+    "NB0468": 3.351,
+    "NB0497": 3.104,
+    "NB0515": 2.939,
+    "NB0527": 2.855,
+    "NB0656": 2.077,
+    "NB0718": 1.812,
     "NB0816": 1.458,
     "NB0921": 1.187,
+    "NB0926": 1.177,
+    "NB0973": 1.083
+    "IB0945": 1.134
+    "NB1010": 1.013
 }
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py	2023-02-16 21:06:19.306658967 +0900
@@ -10,16 +10,24 @@
 config.densityCutMaxPerPixel = 2000
 config.filterMap = {'g': 'g', 'r': 'r', 'r2': 'r', 'i': 'i', 'i2': 'i',
                     'z': 'z', 'y': 'y',
-                    'N387': 'N387', 'N816': 'N816', 'N921': 'N921',
-                    'N1010': 'N1010'}
-config.primaryBands = ('i', 'r', 'g', 'z', 'y', 'N387', 'N816', 'N921', 'N1010')
+                    'N387': 'N387', 'N391': 'N391', 'N395': 'N395', 
+                    'N400': 'N400', 'N430': 'N430', 'N468': 'N468', 
+                    'N497': 'N497', 'N515': 'N515', 'N527': 'N527', 
+                    'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 
+                    'N921': 'N921', 'N926': 'N926', 'I945': 'I945', 
+                    'N973': 'N973', 'N1010': 'N1010'}
+config.primaryBands = ('i', 'r', 'g', 'z', 'y', 'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
 config.doSubtractLocalBackground = True
 
 config.fgcmLoadReferenceCatalog.refObjLoader.ref_dataset_name = 'ps1_pv3_3pi_20170110'
 config.fgcmLoadReferenceCatalog.refFilterMap = {'g': 'g', 'r': 'r', 'r2': 'r',
                                                 'i': 'i', 'i2': 'i', 'z': 'z', 'y': 'y',
-                                                'N387': 'g', 'N816': 'i', 'N921': 'z',
-                                                'N1010': 'y'}
+                                                'N387': 'g', 'N391': 'g', 'N395': 'g', 
+                                                'N400': 'g', 'N430': 'g', 'N468': 'g', 
+                                                'N497': 'g', 'N515': 'g', 'N527': 'g', 
+                                                'N656': 'r', 'N718': 'i', 'N816': 'i', 
+                                                'N921': 'z', 'N926': 'z', 'I945': 'y', 
+                                                'N973': 'y', 'N1010': 'y'}
 config.fgcmLoadReferenceCatalog.applyColorTerms = True
 hscConfigDir = os.path.join(getPackageDir("obs_subaru"), "config", "hsc")
 config.fgcmLoadReferenceCatalog.colorterms.load(os.path.join(hscConfigDir, 'colorterms.py'))
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py	2023-02-16 21:06:19.306658967 +0900
@@ -16,11 +16,24 @@
                                             'fgcmOutputProducts.py'))
 config.fgcmFitCycle.aperCorrFitNBins = 0
 config.fgcmFitCycle.useRepeatabilityForExpGrayCutsDict = {'N387': True,
+                                                          'N391': True,
+                                                          'N395': True,
+                                                          'N400': True,
+                                                          'N430': True,
+                                                          'N468': True,
+                                                          'N497': True,
                                                           'g': True,
+                                                          'N515': True,
+                                                          'N527': True,
+                                                          'N656': True,
                                                           'r': True,
+                                                          'N718': True,
                                                           'i': True,
                                                           'N816': True,
                                                           'z': True,
                                                           'N921': True,
+                                                          'N926': True,
+                                                          'I945': True,
+                                                          'N973': True,
                                                           'y': True,
                                                           'N1010': True}
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py	2023-02-16 21:06:19.306658967 +0900
@@ -5,12 +5,20 @@
 from lsst.fgcmcal import Sedterm, Sedboundaryterm
 
 config.outfileBase = 'fgcmHscCalibrations'
-config.bands = ['N387', 'g', 'r', 'i', 'N816', 'z', 'N921', 'y', 'N1010']
-config.fitBands = ['N387', 'g', 'r', 'i', 'N816', 'z', 'N921', 'y', 'N1010']
+config.bands = ['N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'g', 
+                'N497', 'N515', 'N527', 'N656','r', 'N718', 'i', 'N816', 
+                'z', 'N921', 'N926', 'I945', 'y', 'N973', 'N1010']
+config.fitBands = ['N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'g', 
+                   'N497', 'N515', 'N527', 'N656','r', 'N718', 'i', 'N816', 
+                   'z', 'N921', 'N926', 'I945', 'y', 'N973', 'N1010']
 config.filterMap = {'g': 'g', 'r': 'r', 'r2': 'r', 'i': 'i', 'i2': 'i',
                     'z': 'z', 'y': 'y',
-                    'N387': 'N387', 'N816': 'N816', 'N921': 'N921',
-                    'N1010': 'N1010'}
+                    'N387': 'N387', 'N391': 'N391', 'N395': 'N395', 
+                    'N400': 'N400', 'N430': 'N430', 'N468': 'N468', 
+                    'N497': 'N497', 'N515': 'N515', 'N527': 'N527', 
+                    'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 
+                    'N921': 'N921', 'N926': 'N926', 'I945': 'I945', 
+                    'N973': 'N973', 'N1010': 'N1010'}
 config.maxIterBeforeFinalCycle = 75
 config.nCore = 4
 config.cycleNumber = 0
@@ -20,32 +28,71 @@
 config.coatingMjds = [56650.0, 58050.0]
 config.latitude = 19.8256
 config.expGrayPhotometricCutDict = {'N387': -0.05,
+                                    'N391': -0.05,
+                                    'N395': -0.05,
+                                    'N400': -0.05,
+                                    'N430': -0.05,
+                                    'N468': -0.05,
                                     'g': -0.05,
+                                    'N497': -0.05,
+                                    'N515': -0.05,
+                                    'N527': -0.05,
+                                    'N656': -0.05,
                                     'r': -0.05,
+                                    'N718': -0.05,
                                     'i': -0.05,
                                     'N816': -0.05,
                                     'z': -0.05,
                                     'N921': -0.05,
+                                    'N926': -0.05,
+                                    'I945': -0.05,
                                     'y': -0.05,
+                                    'N973': -0.05,
                                     'N1010': -0.05}
 config.expGrayHighCutDict = {'N387': 0.2,
+                             'N391': 0.2,
+                             'N395': 0.2,
+                             'N400': 0.2,
+                             'N430': 0.2,
+                             'N468': 0.2,
                              'g': 0.2,
+                             'N497': 0.2,
+                             'N515': 0.2,
+                             'N527': 0.2,
+                             'N656': 0.2,
                              'r': 0.2,
+                             'N718': 0.2,
                              'i': 0.2,
                              'N816': 0.2,
                              'z': 0.2,
                              'N921': 0.2,
+                             'N926': 0.2,
+                             'I945': 0.2,
                              'y': 0.2,
+                             'N973': 0.2,
                              'N1010': 0.2}
 config.aperCorrFitNBins = 10
 config.aperCorrInputSlopeDict = {'N387': -1.0,
+                                 'N391': -1.0,
+                                 'N395': -1.0,
+                                 'N400': -1.0,
+                                 'N430': -1.0,
+                                 'N468': -1.0,
                                  'g': -1.1579,
+                                 'N497': -1.0,
+                                 'N515': -1.0,
+                                 'N527': -1.0,
+                                 'N656': -1.0,
                                  'r': -1.3908,
+                                 'N718': -1.0,
                                  'i': -1.1436,
                                  'N816': -1.8149,
                                  'z': -1.6974,
                                  'N921': -1.3310,
+                                 'N926': -1.0,
+                                 'I945': -1.0,
                                  'y': -1.2057,
+                                 'N973': -1.0,
                                  'N1010': -1.0}
 config.starColorCuts = ['g,r,-0.25,2.25',
                         'r,i,-0.50,2.25',
@@ -55,63 +102,141 @@
 config.freezeStdAtmosphere = True
 config.precomputeSuperStarInitialCycle = True
 config.superStarSubCcdDict = {'N387': False,
+                              'N391': False,
+                              'N395': False,
+                              'N400': False,
+                              'N430': False,
+                              'N468': False,
                               'g': True,
+                              'N497': False,
+                              'N515': False,
+                              'N527': False,
+                              'N656': False,
                               'r': True,
+                              'N718': False,
                               'i': True,
                               'N816': True,
                               'z': True,
                               'N921': True,
+                              'N926': False,
+                              'I945': False,
                               'y': True,
+                              'N973': False,
                               'N1010': False}
 config.superStarSubCcdChebyshevOrder = 2
 config.ccdGraySubCcdDict = {'N387': False,
+                            'N391': False,
+                            'N395': False,
+                            'N400': False,
+                            'N430': False,
+                            'N468': False,
                             'g': True,
+                            'N497': False,
+                            'N515': False,
+                            'N527': False,
+                            'N656': False,
                             'r': True,
+                            'N718': False,
                             'i': True,
                             'N816': True,
                             'z': True,
                             'N921': True,
+                            'N926': False,
+                            'I945': False,
                             'y': True,
+                            'N973': False,
                             'N1010': False}
 config.instrumentParsPerBand = True
 config.minStarPerExp = 100
 config.expVarGrayPhotometricCutDict = {'N387': 0.05,
+                                       'N391': 0.05,
+                                       'N395': 0.05,
+                                       'N400': 0.05,
+                                       'N430': 0.05,
+                                       'N468': 0.05,
                                        'g': 0.0025,
+                                       'N497': 0.05,
+                                       'N515': 0.05,
+                                       'N527': 0.05,
+                                       'N656': 0.05,
                                        'r': 0.0025,
+                                       'N718': 0.05,
                                        'i': 0.0025,
                                        'N816': 0.05,
                                        'z': 0.0025,
                                        'N921': 0.05,
+                                       'N926': 0.05,
+                                       'I945': 0.05,
                                        'y': 0.0025,
+                                       'N973': 0.05,
                                        'N1010': 0.05}
 config.minExpPerNight = 3
 config.useRepeatabilityForExpGrayCutsDict = {'N387': True,
+                                             'N391': True,
+                                             'N395': True,
+                                             'N400': True,
+                                             'N430': True,
+                                             'N468': True,
                                              'g': False,
+                                             'N497': True,
+                                             'N515': True,
+                                             'N527': True,
+                                             'N656': True,
                                              'r': False,
+                                             'N718': True,
                                              'i': False,
                                              'N816': True,
                                              'z': False,
                                              'N921': True,
+                                             'N926': True,
+                                             'I945': True,
                                              'y': False,
+                                             'N973': True,
                                              'N1010': True}
 config.sigFgcmMaxEGrayDict = {'N387': 0.15,
+                              'N391': 0.15,
+                              'N395': 0.15,
+                              'N400': 0.15,
+                              'N430': 0.15,
+                              'N468': 0.15,
                               'g': 0.05,
+                              'N497': 0.15,
+                              'N515': 0.15,
+                              'N527': 0.15,
+                              'N656': 0.15,
                               'r': 0.05,
+                              'N718': 0.15,
                               'i': 0.05,
                               'N816': 0.15,
                               'z': 0.05,
                               'N921': 0.15,
+                              'N926': 0.15,
+                              'I945': 0.15,
                               'y': 0.05,
+                              'N973': 0.15,
                               'N1010': 0.15}
 config.approxThroughputDict = {'N387': 1.0,
-                              'g': 1.0,
-                              'r': 1.0,
-                              'i': 1.0,
-                              'N816': 1.0,
-                              'z': 1.0,
-                              'N921': 1.0,
-                              'y': 1.0,
-                              'N1010': 1.0}
+                               'N391': 1.0,
+                               'N395': 1.0,
+                               'N400': 1.0,
+                               'N430': 1.0,
+                               'N468': 1.0,
+                               'g': 1.0,
+                               'N497': 1.0,
+                               'N515': 1.0,
+                               'N527': 1.0,
+                               'N656': 1.0,
+                               'r': 1.0,
+                               'N718': 1.0,
+                               'i': 1.0,
+                               'N816': 1.0,
+                               'z': 1.0,
+                               'N921': 1.0,
+                               'N926': 1.0,
+                               'I945': 1.0,
+                               'y': 1.0,
+                               'N973': 1.0,
+                               'N1010': 1.0}
 
 from lsst.fgcmcal import Sedterm, Sedboundaryterm
 config.sedboundaryterms.data = {'gr': Sedboundaryterm(primary='g', secondary='r'),
@@ -119,8 +244,21 @@
                                 'iz': Sedboundaryterm(primary='i', secondary='z'),
                                 'zy': Sedboundaryterm(primary='z', secondary='y'),
                                 'N387g': Sedboundaryterm(primary='N387', secondary='g'),
+                                'N391g': Sedboundaryterm(primary='N391', secondary='g'),
+                                'N395g': Sedboundaryterm(primary='N395', secondary='g'),
+                                'N400g': Sedboundaryterm(primary='N400', secondary='g'),
+                                'N430g': Sedboundaryterm(primary='N430', secondary='g'),
+                                'N468g': Sedboundaryterm(primary='N468', secondary='g'),
+                                'N497g': Sedboundaryterm(primary='N497', secondary='g'),
+                                'N515g': Sedboundaryterm(primary='N515', secondary='g'),
+                                'N527g': Sedboundaryterm(primary='N527', secondary='g'),
+                                'N656i': Sedboundaryterm(primary='N656', secondary='i'),
+                                'N718i': Sedboundaryterm(primary='N718', secondary='i'),
                                 'N816i': Sedboundaryterm(primary='N816', secondary='i'),
                                 'N921z': Sedboundaryterm(primary='N921', secondary='z'),
+                                'N926z': Sedboundaryterm(primary='N926', secondary='z'),
+                                'I945z': Sedboundaryterm(primary='I945', secondary='z'),
+                                'N973y': Sedboundaryterm(primary='N973', secondary='y'),
                                 'N1010y': Sedboundaryterm(primary='N1010', secondary='y')}
 config.sedterms.data = {'g': Sedterm(primaryTerm='gr', secondaryTerm='ri', constant=1.6),
                         'r': Sedterm(primaryTerm='gr', secondaryTerm='ri', constant=0.9),
@@ -130,6 +268,19 @@
                                      extrapolated=True, primaryBand='y', secondaryBand='z',
                                      tertiaryBand='i'),
                         'N387': Sedterm(primaryTerm='N387g', constant=1.0),
+                        'N391': Sedterm(primaryTerm='N391g', constant=1.0),
+                        'N395': Sedterm(primaryTerm='N395g', constant=1.0),
+                        'N400': Sedterm(primaryTerm='N400g', constant=1.0),
+                        'N430': Sedterm(primaryTerm='N430g', constant=1.0),
+                        'N468': Sedterm(primaryTerm='N468g', constant=1.0),
+                        'N497': Sedterm(primaryTerm='N497g', constant=1.0),
+                        'N515': Sedterm(primaryTerm='N515g', constant=1.0),
+                        'N527': Sedterm(primaryTerm='N527g', constant=1.0),
+                        'N656': Sedterm(primaryTerm='N656i', constant=0.7),
+                        'N718': Sedterm(primaryTerm='N718i', constant=1.0),
                         'N816': Sedterm(primaryTerm='N816i', constant=0.7),
                         'N921': Sedterm(primaryTerm='N921z', constant=0.5),
+                        'N926': Sedterm(primaryTerm='N926z', constant=1.0),
+                        'I945': Sedterm(primaryTerm='I945z', constant=1.0),
+                        'N973': Sedterm(primaryTerm='N973y', constant=1.0),
                         'N1010': Sedterm(primaryTerm='N1010y', constant=1.0)}
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py	2023-02-16 21:06:19.306658967 +0900
@@ -4,13 +4,13 @@
 
 # Filter names to build LUT ('short' names)
 config.filterNames = ('g', 'r', 'r2', 'i', 'i2', 'z', 'y',
-                      'N387', 'N816', 'N921', 'N1010')
+                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
 
 # Standard filterNames ('short' names)
 # These settings will put both "r" and "r2" filters on the
 # "r2" standard, and similar for "i" and "i2".
 config.stdFilterNames = ('g', 'r2', 'r2', 'i2', 'i2', 'z', 'y',
-                         'N387', 'N816', 'N921', 'N1010')
+                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
 
 # FGCM name or filename of precomputed atmospheres
 config.atmosphereTableName = 'fgcm_atm_subaru3'
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-02-16 21:06:02.218247985 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-02-16 21:06:19.306658967 +0900
@@ -37,6 +37,7 @@
         ('NB0387', 'g'),
         ('NB0391', 'g'),
         ('NB0395', 'g'),
+        ('NB0400', 'g'),
         ('NB0430', 'g'),
         ('NB0468', 'g'),
         ('NB0497', 'g'),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py	2023-02-16 21:06:19.307658991 +0900
@@ -1,2 +1,2 @@
 config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "NB0921", "NB0816",
-                       "NB1010", "NB0387", "NB0515", ]
+                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945", ]
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py	2023-02-16 21:06:19.307658991 +0900
@@ -1,2 +1,2 @@
 config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "NB0921", "NB0816",
-                       "NB1010", "NB0387", "NB0515", ]
+                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945", ]
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py	2021-11-19 16:05:31.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py	2023-02-16 21:06:19.307658991 +0900
@@ -88,4 +88,13 @@
                      abstract_filter='N926', lambdaEff=926),
     FilterDefinition(physical_filter="NB0400",
                      abstract_filter='N400', lambdaEff=400),
+    FilterDefinition(physical_filter="NB0391",
+                     abstract_filter='N391', lambdaEff=391),
+    FilterDefinition(physical_filter="NB0395",
+                     abstract_filter='N395', lambdaEff=395),
+    FilterDefinition(physical_filter="NB0430",
+                     abstract_filter='N430', lambdaEff=430),
+    FilterDefinition(physical_filter="NB0497",
+                     abstract_filter='N497', lambdaEff=497),
+
 )
__eof__
fi

if [ $version -le 2 ]
then
patch -p7 << "__eof__"
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-02-16 21:06:19.305658943 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-02-02 09:18:18.000000000 +0900
@@ -74,6 +74,7 @@
         'i2': Colorterm(primary="i", secondary="z", c0=0.001625, c1=-0.200406, c2=-0.013666),
         'z': Colorterm(primary="z", secondary="y", c0=-0.005362, c1=-0.221551, c2=-0.308279),
         'y': Colorterm(primary="y", secondary="z", c0=-0.002055, c1=0.209680, c2=0.227296),
+        'EBgri': Colorterm(primary="g", secondary="i",c0=-0.021905, c1=-0.500088, c2=-0.064044),
         'I945': Colorterm(primary="y", secondary="z", c0=0.005275, c1=-0.194285, c2=-0.125424),
         'N387': Colorterm(primary="g", secondary="r", c0=0.427879, c1=1.869068, c2=0.540580),
         'N391': Colorterm(primary="g", secondary="r",c0=0.386888, c1=1.688354, c2=0.525252),
@@ -82,6 +83,7 @@
         'N430': Colorterm(primary="g", secondary="r",c0=0.121335, c1=0.809929, c2=0.126250),
         'N468': Colorterm(primary="g", secondary="r", c0=-0.042240, c1=0.121756, c2=0.027599),
         'N497': Colorterm(primary="g", secondary="r",c0=-0.044134, c1=-0.168663, c2=0.052961),
+        'N506': Colorterm(primary="g", secondary="r",c0=-0.034107, c1=-0.223229, c2=0.094362),
         'N515': Colorterm(primary="g", secondary="r", c0=-0.021913, c1=-0.253159, c2=0.151553),
         'N527': Colorterm(primary="g", secondary="r", c0=-0.020641, c1=-0.366167, c2=0.038497),
         'N656': Colorterm(primary="r", secondary="i", c0=0.035655, c1=-0.512046, c2=0.042796),
@@ -100,6 +102,7 @@
         'HSC-I2': Colorterm(primary="i", secondary="z", c0=0.001625, c1=-0.200406, c2=-0.013666),
         'HSC-Z': Colorterm(primary="z", secondary="y", c0=-0.005362, c1=-0.221551, c2=-0.308279),
         'HSC-Y': Colorterm(primary="y", secondary="z", c0=-0.002055, c1=0.209680, c2=0.227296),
+        'EB-GRI': Colorterm(primary="g", secondary="i",c0=-0.021905, c1=-0.500088, c2=-0.064044),
         'IB0945': Colorterm(primary="y", secondary="z", c0=0.005275, c1=-0.194285, c2=-0.125424),
         'NB0387': Colorterm(primary="g", secondary="r", c0=0.427879, c1=1.869068, c2=0.540580),
         'NB0391': Colorterm(primary="g", secondary="r",c0=0.386888, c1=1.688354, c2=0.525252),
@@ -108,6 +111,7 @@
         'NB0430': Colorterm(primary="g", secondary="r",c0=0.121335, c1=0.809929, c2=0.126250),
         'NB0468': Colorterm(primary="g", secondary="r", c0=-0.042240, c1=0.121756, c2=0.027599),
         'NB0497': Colorterm(primary="g", secondary="r",c0=-0.044134, c1=-0.168663, c2=0.052961),
+        'NB0506': Colorterm(primary="g", secondary="r",c0=-0.034107, c1=-0.223229, c2=0.094362),
         'NB0515': Colorterm(primary="g", secondary="r", c0=-0.021913, c1=-0.253159, c2=0.151553),
         'NB0527': Colorterm(primary="g", secondary="r", c0=-0.020641, c1=-0.366167, c2=0.038497),
         'NB0656': Colorterm(primary="r", secondary="i", c0=0.035655, c1=-0.512046, c2=0.042796),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py	2023-02-16 21:06:19.305658943 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py	2023-02-16 10:36:04.000000000 +0900
@@ -8,6 +8,7 @@
     "HSC-I": 1.617,
     "HSC-Z": 1.261,
     "HSC-Y": 1.074,
+    "EB-GRI": 2.422,
     "NB0387": 4.007,
     "NB0391": 3.960,
     "NB0395": 3.929,
@@ -15,6 +16,7 @@
     "NB0430": 3.661,
     "NB0468": 3.351,
     "NB0497": 3.104,
+    "NB0506": 3.026,
     "NB0515": 2.939,
     "NB0527": 2.855,
     "NB0656": 2.077,
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py	2023-02-16 21:06:19.306658967 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py	2023-02-01 17:05:45.000000000 +0900
@@ -9,22 +9,23 @@
 config.minPerBand = 2
 config.densityCutMaxPerPixel = 2000
 config.filterMap = {'g': 'g', 'r': 'r', 'r2': 'r', 'i': 'i', 'i2': 'i',
-                    'z': 'z', 'y': 'y',
+                    'z': 'z', 'y': 'y', 'EBgri': 'EBgri',
                     'N387': 'N387', 'N391': 'N391', 'N395': 'N395', 
                     'N400': 'N400', 'N430': 'N430', 'N468': 'N468', 
-                    'N497': 'N497', 'N515': 'N515', 'N527': 'N527', 
+                    'N497': 'N497', 'N506': 'N506', 'N515': 'N515', 'N527': 'N527', 
                     'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 
                     'N921': 'N921', 'N926': 'N926', 'I945': 'I945', 
                     'N973': 'N973', 'N1010': 'N1010'}
-config.primaryBands = ('i', 'r', 'g', 'z', 'y', 'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
+config.primaryBands = ('i', 'r', 'g', 'z', 'y', 'EBgri', 'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
 config.doSubtractLocalBackground = True
 
 config.fgcmLoadReferenceCatalog.refObjLoader.ref_dataset_name = 'ps1_pv3_3pi_20170110'
 config.fgcmLoadReferenceCatalog.refFilterMap = {'g': 'g', 'r': 'r', 'r2': 'r',
                                                 'i': 'i', 'i2': 'i', 'z': 'z', 'y': 'y',
+                                                'EBgri': 'r',
                                                 'N387': 'g', 'N391': 'g', 'N395': 'g', 
                                                 'N400': 'g', 'N430': 'g', 'N468': 'g', 
-                                                'N497': 'g', 'N515': 'g', 'N527': 'g', 
+                                                'N497': 'g', 'N506': 'g', 'N515': 'g', 'N527': 'g', 
                                                 'N656': 'r', 'N718': 'i', 'N816': 'i', 
                                                 'N921': 'z', 'N926': 'z', 'I945': 'y', 
                                                 'N973': 'y', 'N1010': 'y'}
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py	2023-02-16 21:06:19.306658967 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py	2023-02-01 17:03:38.000000000 +0900
@@ -23,10 +23,13 @@
                                                           'N468': True,
                                                           'N497': True,
                                                           'g': True,
+                                                          'N506': True,
                                                           'N515': True,
                                                           'N527': True,
                                                           'N656': True,
+                                                          'EBgri': True,
                                                           'r': True,
+                                                          'EBgri': True,
                                                           'N718': True,
                                                           'i': True,
                                                           'N816': True,
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py	2023-02-16 21:06:19.306658967 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py	2023-02-01 17:14:18.000000000 +0900
@@ -6,16 +6,16 @@
 
 config.outfileBase = 'fgcmHscCalibrations'
 config.bands = ['N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'g', 
-                'N497', 'N515', 'N527', 'N656','r', 'N718', 'i', 'N816', 
+                'N497', 'N506', 'N515', 'N527', 'N656', 'EBgri', 'r', 'N718', 'i', 'N816', 
                 'z', 'N921', 'N926', 'I945', 'y', 'N973', 'N1010']
 config.fitBands = ['N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'g', 
-                   'N497', 'N515', 'N527', 'N656','r', 'N718', 'i', 'N816', 
+                   'N497', 'N506', 'N515', 'N527', 'N656', 'EBgri','r', 'N718', 'i', 'N816', 
                    'z', 'N921', 'N926', 'I945', 'y', 'N973', 'N1010']
 config.filterMap = {'g': 'g', 'r': 'r', 'r2': 'r', 'i': 'i', 'i2': 'i',
-                    'z': 'z', 'y': 'y',
+                    'z': 'z', 'y': 'y', 'EBgri': 'EBgri',
                     'N387': 'N387', 'N391': 'N391', 'N395': 'N395', 
                     'N400': 'N400', 'N430': 'N430', 'N468': 'N468', 
-                    'N497': 'N497', 'N515': 'N515', 'N527': 'N527', 
+                    'N497': 'N497', 'N506': 'N506', 'N515': 'N515', 'N527': 'N527', 
                     'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 
                     'N921': 'N921', 'N926': 'N926', 'I945': 'I945', 
                     'N973': 'N973', 'N1010': 'N1010'}
@@ -35,9 +35,11 @@
                                     'N468': -0.05,
                                     'g': -0.05,
                                     'N497': -0.05,
+                                    'N506': -0.05,
                                     'N515': -0.05,
                                     'N527': -0.05,
                                     'N656': -0.05,
+                                    'EBgri': -0.05,
                                     'r': -0.05,
                                     'N718': -0.05,
                                     'i': -0.05,
@@ -57,9 +59,11 @@
                              'N468': 0.2,
                              'g': 0.2,
                              'N497': 0.2,
+                             'N506': 0.2,
                              'N515': 0.2,
                              'N527': 0.2,
                              'N656': 0.2,
+                             'EBgri': 0.2,
                              'r': 0.2,
                              'N718': 0.2,
                              'i': 0.2,
@@ -80,9 +84,11 @@
                                  'N468': -1.0,
                                  'g': -1.1579,
                                  'N497': -1.0,
+                                 'N506': -1.0,
                                  'N515': -1.0,
                                  'N527': -1.0,
                                  'N656': -1.0,
+                                 'EBgri': -1.0,
                                  'r': -1.3908,
                                  'N718': -1.0,
                                  'i': -1.1436,
@@ -109,9 +115,11 @@
                               'N468': False,
                               'g': True,
                               'N497': False,
+                              'N506': False,
                               'N515': False,
                               'N527': False,
                               'N656': False,
+                              'EBgri': False,
                               'r': True,
                               'N718': False,
                               'i': True,
@@ -132,9 +140,11 @@
                             'N468': False,
                             'g': True,
                             'N497': False,
+                            'N506': False,
                             'N515': False,
                             'N527': False,
                             'N656': False,
+                            'EBgri': False,
                             'r': True,
                             'N718': False,
                             'i': True,
@@ -156,9 +166,11 @@
                                        'N468': 0.05,
                                        'g': 0.0025,
                                        'N497': 0.05,
+                                       'N506': 0.05,
                                        'N515': 0.05,
                                        'N527': 0.05,
                                        'N656': 0.05,
+                                       'EBgri': 0.05,
                                        'r': 0.0025,
                                        'N718': 0.05,
                                        'i': 0.0025,
@@ -179,9 +191,11 @@
                                              'N468': True,
                                              'g': False,
                                              'N497': True,
+                                             'N506': True,
                                              'N515': True,
                                              'N527': True,
                                              'N656': True,
+                                             'EBgri': True,
                                              'r': False,
                                              'N718': True,
                                              'i': False,
@@ -201,9 +215,11 @@
                               'N468': 0.15,
                               'g': 0.05,
                               'N497': 0.15,
+                              'N506': 0.15,
                               'N515': 0.15,
                               'N527': 0.15,
                               'N656': 0.15,
+                              'EBgri': 0.15,
                               'r': 0.05,
                               'N718': 0.15,
                               'i': 0.05,
@@ -223,9 +239,11 @@
                                'N468': 1.0,
                                'g': 1.0,
                                'N497': 1.0,
+                               'N506': 1.0,
                                'N515': 1.0,
                                'N527': 1.0,
                                'N656': 1.0,
+                               'EBgri': 1.0,
                                'r': 1.0,
                                'N718': 1.0,
                                'i': 1.0,
@@ -233,7 +251,7 @@
                                'z': 1.0,
                                'N921': 1.0,
                                'N926': 1.0,
-                               'I945': 1.0,
+                               'I9945': 1.0,
                                'y': 1.0,
                                'N973': 1.0,
                                'N1010': 1.0}
@@ -243,6 +261,7 @@
                                 'ri': Sedboundaryterm(primary='r', secondary='i'),
                                 'iz': Sedboundaryterm(primary='i', secondary='z'),
                                 'zy': Sedboundaryterm(primary='z', secondary='y'),
+                                'EBgrir': Sedboundaryterm(primary='EBgri', secondary='r'),
                                 'N387g': Sedboundaryterm(primary='N387', secondary='g'),
                                 'N391g': Sedboundaryterm(primary='N391', secondary='g'),
                                 'N395g': Sedboundaryterm(primary='N395', secondary='g'),
@@ -250,6 +269,7 @@
                                 'N430g': Sedboundaryterm(primary='N430', secondary='g'),
                                 'N468g': Sedboundaryterm(primary='N468', secondary='g'),
                                 'N497g': Sedboundaryterm(primary='N497', secondary='g'),
+                                'N506g': Sedboundaryterm(primary='N506', secondary='g'),
                                 'N515g': Sedboundaryterm(primary='N515', secondary='g'),
                                 'N527g': Sedboundaryterm(primary='N527', secondary='g'),
                                 'N656i': Sedboundaryterm(primary='N656', secondary='i'),
@@ -267,6 +287,7 @@
                         'y': Sedterm(primaryTerm='zy', secondaryTerm='iz', constant=0.25,
                                      extrapolated=True, primaryBand='y', secondaryBand='z',
                                      tertiaryBand='i'),
+                        'EBgri': Sedterm(primaryTerm='EBgrir', constant=1.0),
                         'N387': Sedterm(primaryTerm='N387g', constant=1.0),
                         'N391': Sedterm(primaryTerm='N391g', constant=1.0),
                         'N395': Sedterm(primaryTerm='N395g', constant=1.0),
@@ -274,6 +295,7 @@
                         'N430': Sedterm(primaryTerm='N430g', constant=1.0),
                         'N468': Sedterm(primaryTerm='N468g', constant=1.0),
                         'N497': Sedterm(primaryTerm='N497g', constant=1.0),
+                        'N506': Sedterm(primaryTerm='N506g', constant=1.0),
                         'N515': Sedterm(primaryTerm='N515g', constant=1.0),
                         'N527': Sedterm(primaryTerm='N527g', constant=1.0),
                         'N656': Sedterm(primaryTerm='N656i', constant=0.7),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py	2023-02-16 21:06:19.306658967 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py	2023-02-01 17:04:22.000000000 +0900
@@ -3,14 +3,14 @@
 """
 
 # Filter names to build LUT ('short' names)
-config.filterNames = ('g', 'r', 'r2', 'i', 'i2', 'z', 'y',
-                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
+config.filterNames = ('g', 'r', 'r2', 'i', 'i2', 'z', 'y', 'EBgri',
+                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
 
 # Standard filterNames ('short' names)
 # These settings will put both "r" and "r2" filters on the
 # "r2" standard, and similar for "i" and "i2".
-config.stdFilterNames = ('g', 'r2', 'r2', 'i2', 'i2', 'z', 'y',
-                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
+config.stdFilterNames = ('g', 'r2', 'r2', 'i2', 'i2', 'z', 'y', 'EBgri',
+                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
 
 # FGCM name or filename of precomputed atmospheres
 config.atmosphereTableName = 'fgcm_atm_subaru3'
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-02-16 21:06:19.306658967 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-02-13 18:20:24.000000000 +0900
@@ -3,6 +3,7 @@
         # Wide bands
         ("r2", "r"),
         ("i2", "i"),
+        ("EBgri", "r"),
         # Narrow bands
         ('N387', 'g'),
         ('N391', 'g'),
@@ -11,6 +12,7 @@
         ('N430', 'g'),
         ('N468', 'g'),
         ('N497', 'g'),
+        ('N506', 'g'),
         ('N515', 'g'),
         ('N527', 'g'),
         ('N656', 'r'),
@@ -33,6 +35,7 @@
         ("HSC-I2", "i"),
         ("HSC-Z", "z"),
         ("HSC-Y", "y"),
+        ("EB-GRI", "r"),
         # Narrow bands
         ('NB0387', 'g'),
         ('NB0391', 'g'),
@@ -41,6 +44,7 @@
         ('NB0430', 'g'),
         ('NB0468', 'g'),
         ('NB0497', 'g'),
+        ('NB0506', 'g'),
         ('NB0515', 'g'),
         ('NB0527', 'g'),
         ('NB0656', 'r'),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py	2023-02-16 21:06:19.307658991 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py	2023-02-13 18:51:43.000000000 +0900
@@ -1,2 +1,2 @@
-config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "NB0921", "NB0816",
-                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945", ]
+config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "EB-GRI", "NB0921", "NB0816",
+                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0506", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945" ]
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py	2023-02-16 21:06:19.307658991 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py	2023-02-13 18:52:01.000000000 +0900
@@ -1,2 +1,2 @@
-config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "NB0921", "NB0816",
-                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945", ]
+config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "EB-GRI", "NB0921", "NB0816",
+                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0506", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945" ]
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/README.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/README.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/README.txt	2021-11-19 16:05:32.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/README.txt	2023-02-01 17:39:54.000000000 +0900
@@ -31,3 +31,6 @@
 modtran_maunakea_am12_pwv15_binned10ang.dat: MODTRAN model for the
 atmospheric absorption generated by Naoki Yasuda, assuming airmass 1.2 and
 PWV=1.5mm.
+
+# Ken Mawatari (NAOJ) modification
+We rename wHSC-EB-gri.txt to wHSC-EBgri.txt to correctly treat the filter in makeTransmissionCurves.py. 
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-EBgri.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-EBgri.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-EBgri.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-EBgri.txt	2022-02-08 12:04:39.000000000 +0900
@@ -0,0 +1,2752 @@
+# wavelength[angstrom]  transmittance
+3500.0 0.0000
+3502.0 0.0000
+3504.0 0.0000
+3506.0 0.0000
+3508.0 0.0000
+3510.0 0.0000
+3512.0 0.0000
+3514.0 0.0000
+3516.0 0.0000
+3518.0 0.0000
+3520.0 0.0000
+3522.0 0.0000
+3524.0 0.0000
+3526.0 0.0000
+3528.0 0.0000
+3530.0 0.0000
+3532.0 0.0000
+3534.0 0.0000
+3536.0 0.0000
+3538.0 0.0000
+3540.0 0.0000
+3542.0 0.0000
+3544.0 0.0000
+3546.0 0.0000
+3548.0 0.0000
+3550.0 0.0000
+3552.0 0.0000
+3554.0 0.0000
+3556.0 0.0000
+3558.0 0.0000
+3560.0 0.0000
+3562.0 0.0000
+3564.0 0.0000
+3566.0 0.0000
+3568.0 0.0000
+3570.0 0.0000
+3572.0 0.0000
+3574.0 0.0000
+3576.0 0.0000
+3578.0 0.0000
+3580.0 0.0000
+3582.0 0.0000
+3584.0 0.0000
+3586.0 0.0000
+3588.0 0.0000
+3590.0 0.0000
+3592.0 0.0000
+3594.0 0.0000
+3596.0 0.0000
+3598.0 0.0000
+3600.0 0.0000
+3602.0 0.0000
+3604.0 0.0000
+3606.0 0.0000
+3608.0 0.0000
+3610.0 0.0000
+3612.0 0.0000
+3614.0 0.0000
+3616.0 0.0000
+3618.0 0.0000
+3620.0 0.0000
+3622.0 0.0000
+3624.0 0.0000
+3626.0 0.0000
+3628.0 0.0000
+3630.0 0.0000
+3632.0 0.0000
+3634.0 0.0000
+3636.0 0.0000
+3638.0 0.0000
+3640.0 0.0000
+3642.0 0.0000
+3644.0 0.0000
+3646.0 0.0000
+3648.0 0.0000
+3650.0 0.0000
+3652.0 0.0000
+3654.0 0.0000
+3656.0 0.0000
+3658.0 0.0000
+3660.0 0.0000
+3662.0 0.0000
+3664.0 0.0000
+3666.0 0.0000
+3668.0 0.0000
+3670.0 0.0000
+3672.0 0.0000
+3674.0 0.0000
+3676.0 0.0000
+3678.0 0.0000
+3680.0 0.0000
+3682.0 0.0000
+3684.0 0.0000
+3686.0 0.0000
+3688.0 0.0000
+3690.0 0.0000
+3692.0 0.0001
+3694.0 0.0001
+3696.0 0.0001
+3698.0 0.0002
+3700.0 0.0002
+3702.0 0.0002
+3704.0 0.0002
+3706.0 0.0002
+3708.0 0.0002
+3710.0 0.0003
+3712.0 0.0002
+3714.0 0.0002
+3716.0 0.0002
+3718.0 0.0002
+3720.0 0.0002
+3722.0 0.0002
+3724.0 0.0002
+3726.0 0.0002
+3728.0 0.0002
+3730.0 0.0003
+3732.0 0.0003
+3734.0 0.0003
+3736.0 0.0003
+3738.0 0.0003
+3740.0 0.0003
+3742.0 0.0003
+3744.0 0.0002
+3746.0 0.0002
+3748.0 0.0002
+3750.0 0.0002
+3752.0 0.0002
+3754.0 0.0002
+3756.0 0.0002
+3758.0 0.0002
+3760.0 0.0002
+3762.0 0.0002
+3764.0 0.0002
+3766.0 0.0002
+3768.0 0.0002
+3770.0 0.0002
+3772.0 0.0002
+3774.0 0.0002
+3776.0 0.0002
+3778.0 0.0002
+3780.0 0.0002
+3782.0 0.0002
+3784.0 0.0002
+3786.0 0.0002
+3788.0 0.0002
+3790.0 0.0002
+3792.0 0.0002
+3794.0 0.0002
+3796.0 0.0002
+3798.0 0.0002
+3800.0 0.0002
+3802.0 0.0002
+3804.0 0.0002
+3806.0 0.0002
+3808.0 0.0002
+3810.0 0.0002
+3812.0 0.0002
+3814.0 0.0002
+3816.0 0.0002
+3818.0 0.0002
+3820.0 0.0002
+3822.0 0.0002
+3824.0 0.0002
+3826.0 0.0002
+3828.0 0.0002
+3830.0 0.0002
+3832.0 0.0002
+3834.0 0.0002
+3836.0 0.0002
+3838.0 0.0002
+3840.0 0.0002
+3842.0 0.0002
+3844.0 0.0002
+3846.0 0.0002
+3848.0 0.0001
+3850.0 0.0001
+3852.0 0.0001
+3854.0 0.0001
+3856.0 0.0001
+3858.0 0.0001
+3860.0 0.0001
+3862.0 0.0001
+3864.0 0.0001
+3866.0 0.0001
+3868.0 0.0001
+3870.0 0.0001
+3872.0 0.0002
+3874.0 0.0002
+3876.0 0.0002
+3878.0 0.0002
+3880.0 0.0002
+3882.0 0.0002
+3884.0 0.0003
+3886.0 0.0003
+3888.0 0.0003
+3890.0 0.0004
+3892.0 0.0005
+3894.0 0.0006
+3896.0 0.0006
+3898.0 0.0007
+3900.0 0.0008
+3902.0 0.0010
+3904.0 0.0011
+3906.0 0.0012
+3908.0 0.0014
+3910.0 0.0015
+3912.0 0.0017
+3914.0 0.0019
+3916.0 0.0021
+3918.0 0.0023
+3920.0 0.0025
+3922.0 0.0027
+3924.0 0.0030
+3926.0 0.0033
+3928.0 0.0036
+3930.0 0.0039
+3932.0 0.0042
+3934.0 0.0046
+3936.0 0.0049
+3938.0 0.0053
+3940.0 0.0057
+3942.0 0.0061
+3944.0 0.0066
+3946.0 0.0071
+3948.0 0.0075
+3950.0 0.0080
+3952.0 0.0087
+3954.0 0.0094
+3956.0 0.0101
+3958.0 0.0107
+3960.0 0.0114
+3962.0 0.0124
+3964.0 0.0133
+3966.0 0.0143
+3968.0 0.0152
+3970.0 0.0161
+3972.0 0.0175
+3974.0 0.0188
+3976.0 0.0201
+3978.0 0.0214
+3980.0 0.0227
+3982.0 0.0247
+3984.0 0.0267
+3986.0 0.0286
+3988.0 0.0306
+3990.0 0.0326
+3992.0 0.0355
+3994.0 0.0383
+3996.0 0.0412
+3998.0 0.0441
+4000.0 0.0470
+4002.0 0.0515
+4004.0 0.0559
+4006.0 0.0604
+4008.0 0.0648
+4010.0 0.0693
+4012.0 0.0764
+4014.0 0.0835
+4016.0 0.0906
+4018.0 0.0977
+4020.0 0.1048
+4022.0 0.1163
+4024.0 0.1278
+4026.0 0.1393
+4028.0 0.1508
+4030.0 0.1623
+4032.0 0.1805
+4034.0 0.1988
+4036.0 0.2170
+4038.0 0.2353
+4040.0 0.2535
+4042.0 0.2810
+4044.0 0.3086
+4046.0 0.3361
+4048.0 0.3636
+4050.0 0.3911
+4052.0 0.4272
+4054.0 0.4632
+4056.0 0.4992
+4058.0 0.5353
+4060.0 0.5713
+4062.0 0.6075
+4064.0 0.6437
+4066.0 0.6799
+4068.0 0.7161
+4070.0 0.7523
+4072.0 0.7785
+4074.0 0.8046
+4076.0 0.8308
+4078.0 0.8569
+4080.0 0.8831
+4082.0 0.8973
+4084.0 0.9116
+4086.0 0.9259
+4088.0 0.9401
+4090.0 0.9544
+4092.0 0.9591
+4094.0 0.9637
+4096.0 0.9684
+4098.0 0.9731
+4100.0 0.9778
+4102.0 0.9769
+4104.0 0.9760
+4106.0 0.9751
+4108.0 0.9743
+4110.0 0.9734
+4112.0 0.9716
+4114.0 0.9697
+4116.0 0.9679
+4118.0 0.9661
+4120.0 0.9643
+4122.0 0.9635
+4124.0 0.9628
+4126.0 0.9620
+4128.0 0.9612
+4130.0 0.9605
+4132.0 0.9621
+4134.0 0.9637
+4136.0 0.9653
+4138.0 0.9670
+4140.0 0.9686
+4142.0 0.9700
+4144.0 0.9714
+4146.0 0.9728
+4148.0 0.9742
+4150.0 0.9756
+4152.0 0.9765
+4154.0 0.9773
+4156.0 0.9782
+4158.0 0.9791
+4160.0 0.9800
+4162.0 0.9800
+4164.0 0.9800
+4166.0 0.9800
+4168.0 0.9799
+4170.0 0.9799
+4172.0 0.9807
+4174.0 0.9815
+4176.0 0.9822
+4178.0 0.9830
+4180.0 0.9837
+4182.0 0.9845
+4184.0 0.9854
+4186.0 0.9862
+4188.0 0.9870
+4190.0 0.9878
+4192.0 0.9871
+4194.0 0.9864
+4196.0 0.9858
+4198.0 0.9851
+4200.0 0.9844
+4202.0 0.9844
+4204.0 0.9843
+4206.0 0.9842
+4208.0 0.9841
+4210.0 0.9840
+4212.0 0.9841
+4214.0 0.9841
+4216.0 0.9842
+4218.0 0.9842
+4220.0 0.9843
+4222.0 0.9844
+4224.0 0.9845
+4226.0 0.9846
+4228.0 0.9847
+4230.0 0.9848
+4232.0 0.9838
+4234.0 0.9827
+4236.0 0.9816
+4238.0 0.9806
+4240.0 0.9795
+4242.0 0.9793
+4244.0 0.9791
+4246.0 0.9788
+4248.0 0.9786
+4250.0 0.9784
+4252.0 0.9787
+4254.0 0.9790
+4256.0 0.9793
+4258.0 0.9796
+4260.0 0.9799
+4262.0 0.9804
+4264.0 0.9809
+4266.0 0.9813
+4268.0 0.9818
+4270.0 0.9822
+4272.0 0.9821
+4274.0 0.9819
+4276.0 0.9818
+4278.0 0.9816
+4280.0 0.9815
+4282.0 0.9814
+4284.0 0.9813
+4286.0 0.9811
+4288.0 0.9810
+4290.0 0.9809
+4292.0 0.9814
+4294.0 0.9819
+4296.0 0.9825
+4298.0 0.9830
+4300.0 0.9835
+4302.0 0.9841
+4304.0 0.9848
+4306.0 0.9854
+4308.0 0.9860
+4310.0 0.9866
+4312.0 0.9863
+4314.0 0.9861
+4316.0 0.9858
+4318.0 0.9855
+4320.0 0.9852
+4322.0 0.9844
+4324.0 0.9836
+4326.0 0.9828
+4328.0 0.9819
+4330.0 0.9811
+4332.0 0.9815
+4334.0 0.9818
+4336.0 0.9821
+4338.0 0.9824
+4340.0 0.9828
+4342.0 0.9828
+4344.0 0.9828
+4346.0 0.9828
+4348.0 0.9829
+4350.0 0.9829
+4352.0 0.9826
+4354.0 0.9822
+4356.0 0.9819
+4358.0 0.9816
+4360.0 0.9813
+4362.0 0.9803
+4364.0 0.9794
+4366.0 0.9784
+4368.0 0.9775
+4370.0 0.9765
+4372.0 0.9762
+4374.0 0.9759
+4376.0 0.9756
+4378.0 0.9752
+4380.0 0.9749
+4382.0 0.9756
+4384.0 0.9762
+4386.0 0.9769
+4388.0 0.9775
+4390.0 0.9782
+4392.0 0.9790
+4394.0 0.9797
+4396.0 0.9804
+4398.0 0.9812
+4400.0 0.9819
+4402.0 0.9821
+4404.0 0.9822
+4406.0 0.9824
+4408.0 0.9825
+4410.0 0.9826
+4412.0 0.9825
+4414.0 0.9823
+4416.0 0.9821
+4418.0 0.9819
+4420.0 0.9817
+4422.0 0.9823
+4424.0 0.9829
+4426.0 0.9835
+4428.0 0.9840
+4430.0 0.9846
+4432.0 0.9851
+4434.0 0.9857
+4436.0 0.9862
+4438.0 0.9867
+4440.0 0.9872
+4442.0 0.9872
+4444.0 0.9871
+4446.0 0.9870
+4448.0 0.9869
+4450.0 0.9869
+4452.0 0.9863
+4454.0 0.9858
+4456.0 0.9853
+4458.0 0.9848
+4460.0 0.9843
+4462.0 0.9843
+4464.0 0.9842
+4466.0 0.9841
+4468.0 0.9840
+4470.0 0.9840
+4472.0 0.9841
+4474.0 0.9842
+4476.0 0.9843
+4478.0 0.9844
+4480.0 0.9845
+4482.0 0.9844
+4484.0 0.9844
+4486.0 0.9843
+4488.0 0.9843
+4490.0 0.9842
+4492.0 0.9836
+4494.0 0.9829
+4496.0 0.9823
+4498.0 0.9816
+4500.0 0.9810
+4502.0 0.9801
+4504.0 0.9793
+4506.0 0.9784
+4508.0 0.9776
+4510.0 0.9767
+4512.0 0.9767
+4514.0 0.9766
+4516.0 0.9766
+4518.0 0.9766
+4520.0 0.9765
+4522.0 0.9772
+4524.0 0.9779
+4526.0 0.9786
+4528.0 0.9793
+4530.0 0.9800
+4532.0 0.9802
+4534.0 0.9803
+4536.0 0.9805
+4538.0 0.9806
+4540.0 0.9808
+4542.0 0.9809
+4544.0 0.9810
+4546.0 0.9811
+4548.0 0.9811
+4550.0 0.9812
+4552.0 0.9810
+4554.0 0.9808
+4556.0 0.9806
+4558.0 0.9804
+4560.0 0.9802
+4562.0 0.9810
+4564.0 0.9818
+4566.0 0.9825
+4568.0 0.9833
+4570.0 0.9841
+4572.0 0.9844
+4574.0 0.9848
+4576.0 0.9851
+4578.0 0.9855
+4580.0 0.9858
+4582.0 0.9862
+4584.0 0.9865
+4586.0 0.9869
+4588.0 0.9873
+4590.0 0.9876
+4592.0 0.9873
+4594.0 0.9870
+4596.0 0.9867
+4598.0 0.9864
+4600.0 0.9861
+4602.0 0.9860
+4604.0 0.9859
+4606.0 0.9859
+4608.0 0.9858
+4610.0 0.9857
+4612.0 0.9857
+4614.0 0.9857
+4616.0 0.9857
+4618.0 0.9857
+4620.0 0.9857
+4622.0 0.9855
+4624.0 0.9852
+4626.0 0.9850
+4628.0 0.9848
+4630.0 0.9845
+4632.0 0.9843
+4634.0 0.9840
+4636.0 0.9837
+4638.0 0.9835
+4640.0 0.9832
+4642.0 0.9828
+4644.0 0.9825
+4646.0 0.9821
+4648.0 0.9817
+4650.0 0.9813
+4652.0 0.9810
+4654.0 0.9806
+4656.0 0.9802
+4658.0 0.9799
+4660.0 0.9795
+4662.0 0.9796
+4664.0 0.9796
+4666.0 0.9797
+4668.0 0.9797
+4670.0 0.9798
+4672.0 0.9798
+4674.0 0.9799
+4676.0 0.9800
+4678.0 0.9800
+4680.0 0.9801
+4682.0 0.9802
+4684.0 0.9803
+4686.0 0.9805
+4688.0 0.9806
+4690.0 0.9807
+4692.0 0.9802
+4694.0 0.9797
+4696.0 0.9791
+4698.0 0.9786
+4700.0 0.9781
+4702.0 0.9780
+4704.0 0.9780
+4706.0 0.9780
+4708.0 0.9780
+4710.0 0.9780
+4712.0 0.9787
+4714.0 0.9794
+4716.0 0.9801
+4718.0 0.9809
+4720.0 0.9816
+4722.0 0.9816
+4724.0 0.9816
+4726.0 0.9817
+4728.0 0.9817
+4730.0 0.9817
+4732.0 0.9820
+4734.0 0.9822
+4736.0 0.9824
+4738.0 0.9827
+4740.0 0.9829
+4742.0 0.9830
+4744.0 0.9831
+4746.0 0.9832
+4748.0 0.9833
+4750.0 0.9834
+4752.0 0.9831
+4754.0 0.9827
+4756.0 0.9823
+4758.0 0.9819
+4760.0 0.9815
+4762.0 0.9818
+4764.0 0.9821
+4766.0 0.9824
+4768.0 0.9827
+4770.0 0.9830
+4772.0 0.9835
+4774.0 0.9839
+4776.0 0.9844
+4778.0 0.9848
+4780.0 0.9853
+4782.0 0.9856
+4784.0 0.9859
+4786.0 0.9863
+4788.0 0.9866
+4790.0 0.9869
+4792.0 0.9864
+4794.0 0.9860
+4796.0 0.9855
+4798.0 0.9851
+4800.0 0.9846
+4802.0 0.9841
+4804.0 0.9835
+4806.0 0.9830
+4808.0 0.9825
+4810.0 0.9819
+4812.0 0.9814
+4814.0 0.9809
+4816.0 0.9804
+4818.0 0.9798
+4820.0 0.9793
+4822.0 0.9797
+4824.0 0.9801
+4826.0 0.9805
+4828.0 0.9809
+4830.0 0.9813
+4832.0 0.9817
+4834.0 0.9821
+4836.0 0.9825
+4838.0 0.9829
+4840.0 0.9833
+4842.0 0.9832
+4844.0 0.9831
+4846.0 0.9829
+4848.0 0.9828
+4850.0 0.9827
+4852.0 0.9820
+4854.0 0.9813
+4856.0 0.9806
+4858.0 0.9798
+4860.0 0.9791
+4862.0 0.9788
+4864.0 0.9785
+4866.0 0.9783
+4868.0 0.9780
+4870.0 0.9777
+4872.0 0.9780
+4874.0 0.9784
+4876.0 0.9787
+4878.0 0.9791
+4880.0 0.9794
+4882.0 0.9803
+4884.0 0.9811
+4886.0 0.9819
+4888.0 0.9827
+4890.0 0.9835
+4892.0 0.9840
+4894.0 0.9845
+4896.0 0.9851
+4898.0 0.9856
+4900.0 0.9861
+4902.0 0.9859
+4904.0 0.9858
+4906.0 0.9856
+4908.0 0.9855
+4910.0 0.9853
+4912.0 0.9853
+4914.0 0.9853
+4916.0 0.9852
+4918.0 0.9852
+4920.0 0.9851
+4922.0 0.9851
+4924.0 0.9851
+4926.0 0.9852
+4928.0 0.9852
+4930.0 0.9852
+4932.0 0.9855
+4934.0 0.9859
+4936.0 0.9862
+4938.0 0.9866
+4940.0 0.9870
+4942.0 0.9876
+4944.0 0.9883
+4946.0 0.9890
+4948.0 0.9897
+4950.0 0.9904
+4952.0 0.9900
+4954.0 0.9897
+4956.0 0.9894
+4958.0 0.9891
+4960.0 0.9888
+4962.0 0.9887
+4964.0 0.9887
+4966.0 0.9886
+4968.0 0.9886
+4970.0 0.9885
+4972.0 0.9879
+4974.0 0.9873
+4976.0 0.9868
+4978.0 0.9862
+4980.0 0.9856
+4982.0 0.9855
+4984.0 0.9853
+4986.0 0.9852
+4988.0 0.9851
+4990.0 0.9849
+4992.0 0.9849
+4994.0 0.9849
+4996.0 0.9849
+4998.0 0.9849
+5000.0 0.9848
+5002.0 0.9851
+5004.0 0.9854
+5006.0 0.9858
+5008.0 0.9861
+5010.0 0.9864
+5012.0 0.9864
+5014.0 0.9864
+5016.0 0.9864
+5018.0 0.9865
+5020.0 0.9865
+5022.0 0.9863
+5024.0 0.9861
+5026.0 0.9859
+5028.0 0.9857
+5030.0 0.9855
+5032.0 0.9850
+5034.0 0.9844
+5036.0 0.9839
+5038.0 0.9833
+5040.0 0.9828
+5042.0 0.9828
+5044.0 0.9827
+5046.0 0.9827
+5048.0 0.9827
+5050.0 0.9827
+5052.0 0.9827
+5054.0 0.9828
+5056.0 0.9829
+5058.0 0.9829
+5060.0 0.9830
+5062.0 0.9833
+5064.0 0.9837
+5066.0 0.9840
+5068.0 0.9844
+5070.0 0.9847
+5072.0 0.9853
+5074.0 0.9859
+5076.0 0.9865
+5078.0 0.9871
+5080.0 0.9876
+5082.0 0.9877
+5084.0 0.9877
+5086.0 0.9877
+5088.0 0.9878
+5090.0 0.9878
+5092.0 0.9874
+5094.0 0.9869
+5096.0 0.9865
+5098.0 0.9860
+5100.0 0.9856
+5102.0 0.9854
+5104.0 0.9852
+5106.0 0.9850
+5108.0 0.9848
+5110.0 0.9846
+5112.0 0.9850
+5114.0 0.9854
+5116.0 0.9858
+5118.0 0.9861
+5120.0 0.9865
+5122.0 0.9869
+5124.0 0.9872
+5126.0 0.9876
+5128.0 0.9879
+5130.0 0.9882
+5132.0 0.9886
+5134.0 0.9889
+5136.0 0.9893
+5138.0 0.9896
+5140.0 0.9900
+5142.0 0.9895
+5144.0 0.9891
+5146.0 0.9886
+5148.0 0.9882
+5150.0 0.9877
+5152.0 0.9876
+5154.0 0.9874
+5156.0 0.9873
+5158.0 0.9871
+5160.0 0.9870
+5162.0 0.9868
+5164.0 0.9865
+5166.0 0.9863
+5168.0 0.9861
+5170.0 0.9859
+5172.0 0.9861
+5174.0 0.9862
+5176.0 0.9864
+5178.0 0.9865
+5180.0 0.9866
+5182.0 0.9867
+5184.0 0.9867
+5186.0 0.9867
+5188.0 0.9867
+5190.0 0.9867
+5192.0 0.9866
+5194.0 0.9865
+5196.0 0.9865
+5198.0 0.9864
+5200.0 0.9863
+5202.0 0.9864
+5204.0 0.9866
+5206.0 0.9867
+5208.0 0.9869
+5210.0 0.9870
+5212.0 0.9865
+5214.0 0.9861
+5216.0 0.9856
+5218.0 0.9851
+5220.0 0.9846
+5222.0 0.9840
+5224.0 0.9834
+5226.0 0.9828
+5228.0 0.9822
+5230.0 0.9816
+5232.0 0.9815
+5234.0 0.9814
+5236.0 0.9814
+5238.0 0.9813
+5240.0 0.9812
+5242.0 0.9813
+5244.0 0.9814
+5246.0 0.9815
+5248.0 0.9815
+5250.0 0.9816
+5252.0 0.9820
+5254.0 0.9824
+5256.0 0.9828
+5258.0 0.9832
+5260.0 0.9836
+5262.0 0.9838
+5264.0 0.9840
+5266.0 0.9841
+5268.0 0.9843
+5270.0 0.9845
+5272.0 0.9844
+5274.0 0.9843
+5276.0 0.9842
+5278.0 0.9841
+5280.0 0.9840
+5282.0 0.9841
+5284.0 0.9842
+5286.0 0.9843
+5288.0 0.9843
+5290.0 0.9844
+5292.0 0.9843
+5294.0 0.9841
+5296.0 0.9840
+5298.0 0.9838
+5300.0 0.9837
+5302.0 0.9838
+5304.0 0.9840
+5306.0 0.9842
+5308.0 0.9843
+5310.0 0.9845
+5312.0 0.9846
+5314.0 0.9846
+5316.0 0.9847
+5318.0 0.9848
+5320.0 0.9849
+5322.0 0.9851
+5324.0 0.9852
+5326.0 0.9854
+5328.0 0.9856
+5330.0 0.9857
+5332.0 0.9861
+5334.0 0.9864
+5336.0 0.9868
+5338.0 0.9871
+5340.0 0.9875
+5342.0 0.9873
+5344.0 0.9872
+5346.0 0.9871
+5348.0 0.9869
+5350.0 0.9868
+5352.0 0.9868
+5354.0 0.9868
+5356.0 0.9869
+5358.0 0.9869
+5360.0 0.9869
+5362.0 0.9867
+5364.0 0.9865
+5366.0 0.9863
+5368.0 0.9862
+5370.0 0.9860
+5372.0 0.9861
+5374.0 0.9863
+5376.0 0.9865
+5378.0 0.9867
+5380.0 0.9868
+5382.0 0.9872
+5384.0 0.9875
+5386.0 0.9878
+5388.0 0.9881
+5390.0 0.9884
+5392.0 0.9884
+5394.0 0.9883
+5396.0 0.9883
+5398.0 0.9882
+5400.0 0.9882
+5402.0 0.9886
+5404.0 0.9890
+5406.0 0.9895
+5408.0 0.9899
+5410.0 0.9903
+5412.0 0.9899
+5414.0 0.9895
+5416.0 0.9891
+5418.0 0.9886
+5420.0 0.9882
+5422.0 0.9878
+5424.0 0.9874
+5426.0 0.9870
+5428.0 0.9865
+5430.0 0.9861
+5432.0 0.9859
+5434.0 0.9857
+5436.0 0.9855
+5438.0 0.9853
+5440.0 0.9851
+5442.0 0.9849
+5444.0 0.9846
+5446.0 0.9844
+5448.0 0.9842
+5450.0 0.9840
+5452.0 0.9843
+5454.0 0.9846
+5456.0 0.9849
+5458.0 0.9852
+5460.0 0.9855
+5462.0 0.9854
+5464.0 0.9854
+5466.0 0.9853
+5468.0 0.9852
+5470.0 0.9851
+5472.0 0.9853
+5474.0 0.9856
+5476.0 0.9858
+5478.0 0.9861
+5480.0 0.9863
+5482.0 0.9861
+5484.0 0.9859
+5486.0 0.9857
+5488.0 0.9855
+5490.0 0.9852
+5492.0 0.9851
+5494.0 0.9850
+5496.0 0.9849
+5498.0 0.9847
+5500.0 0.9846
+5502.0 0.9842
+5504.0 0.9838
+5506.0 0.9834
+5508.0 0.9830
+5510.0 0.9826
+5512.0 0.9827
+5514.0 0.9827
+5516.0 0.9828
+5518.0 0.9829
+5520.0 0.9829
+5522.0 0.9833
+5524.0 0.9838
+5526.0 0.9842
+5528.0 0.9846
+5530.0 0.9850
+5532.0 0.9850
+5534.0 0.9850
+5536.0 0.9850
+5538.0 0.9850
+5540.0 0.9850
+5542.0 0.9853
+5544.0 0.9855
+5546.0 0.9858
+5548.0 0.9861
+5550.0 0.9863
+5552.0 0.9862
+5554.0 0.9862
+5556.0 0.9861
+5558.0 0.9860
+5560.0 0.9859
+5562.0 0.9858
+5564.0 0.9857
+5566.0 0.9855
+5568.0 0.9854
+5570.0 0.9853
+5572.0 0.9851
+5574.0 0.9849
+5576.0 0.9847
+5578.0 0.9845
+5580.0 0.9844
+5582.0 0.9845
+5584.0 0.9847
+5586.0 0.9848
+5588.0 0.9850
+5590.0 0.9851
+5592.0 0.9853
+5594.0 0.9854
+5596.0 0.9856
+5598.0 0.9857
+5600.0 0.9858
+5602.0 0.9863
+5604.0 0.9868
+5606.0 0.9873
+5608.0 0.9878
+5610.0 0.9883
+5612.0 0.9886
+5614.0 0.9889
+5616.0 0.9892
+5618.0 0.9895
+5620.0 0.9897
+5622.0 0.9902
+5624.0 0.9906
+5626.0 0.9910
+5628.0 0.9915
+5630.0 0.9919
+5632.0 0.9915
+5634.0 0.9910
+5636.0 0.9906
+5638.0 0.9901
+5640.0 0.9897
+5642.0 0.9894
+5644.0 0.9892
+5646.0 0.9889
+5648.0 0.9887
+5650.0 0.9884
+5652.0 0.9881
+5654.0 0.9878
+5656.0 0.9874
+5658.0 0.9871
+5660.0 0.9868
+5662.0 0.9868
+5664.0 0.9867
+5666.0 0.9867
+5668.0 0.9867
+5670.0 0.9866
+5672.0 0.9871
+5674.0 0.9875
+5676.0 0.9879
+5678.0 0.9884
+5680.0 0.9888
+5682.0 0.9886
+5684.0 0.9884
+5686.0 0.9881
+5688.0 0.9879
+5690.0 0.9877
+5692.0 0.9880
+5694.0 0.9882
+5696.0 0.9885
+5698.0 0.9887
+5700.0 0.9890
+5702.0 0.9887
+5704.0 0.9885
+5706.0 0.9882
+5708.0 0.9880
+5710.0 0.9877
+5712.0 0.9874
+5714.0 0.9872
+5716.0 0.9869
+5718.0 0.9866
+5720.0 0.9863
+5722.0 0.9860
+5724.0 0.9858
+5726.0 0.9856
+5728.0 0.9853
+5730.0 0.9851
+5732.0 0.9846
+5734.0 0.9841
+5736.0 0.9837
+5738.0 0.9832
+5740.0 0.9827
+5742.0 0.9829
+5744.0 0.9830
+5746.0 0.9832
+5748.0 0.9834
+5750.0 0.9835
+5752.0 0.9834
+5754.0 0.9834
+5756.0 0.9833
+5758.0 0.9832
+5760.0 0.9831
+5762.0 0.9836
+5764.0 0.9840
+5766.0 0.9844
+5768.0 0.9848
+5770.0 0.9853
+5772.0 0.9857
+5774.0 0.9861
+5776.0 0.9866
+5778.0 0.9870
+5780.0 0.9875
+5782.0 0.9874
+5784.0 0.9874
+5786.0 0.9874
+5788.0 0.9874
+5790.0 0.9874
+5792.0 0.9874
+5794.0 0.9874
+5796.0 0.9875
+5798.0 0.9875
+5800.0 0.9875
+5802.0 0.9875
+5804.0 0.9874
+5806.0 0.9874
+5808.0 0.9873
+5810.0 0.9873
+5812.0 0.9869
+5814.0 0.9866
+5816.0 0.9862
+5818.0 0.9859
+5820.0 0.9855
+5822.0 0.9855
+5824.0 0.9855
+5826.0 0.9854
+5828.0 0.9854
+5830.0 0.9853
+5832.0 0.9859
+5834.0 0.9865
+5836.0 0.9871
+5838.0 0.9877
+5840.0 0.9883
+5842.0 0.9886
+5844.0 0.9890
+5846.0 0.9893
+5848.0 0.9896
+5850.0 0.9899
+5852.0 0.9900
+5854.0 0.9901
+5856.0 0.9902
+5858.0 0.9904
+5860.0 0.9905
+5862.0 0.9906
+5864.0 0.9908
+5866.0 0.9909
+5868.0 0.9910
+5870.0 0.9912
+5872.0 0.9911
+5874.0 0.9911
+5876.0 0.9911
+5878.0 0.9911
+5880.0 0.9911
+5882.0 0.9910
+5884.0 0.9910
+5886.0 0.9910
+5888.0 0.9909
+5890.0 0.9909
+5892.0 0.9905
+5894.0 0.9901
+5896.0 0.9898
+5898.0 0.9894
+5900.0 0.9890
+5902.0 0.9887
+5904.0 0.9883
+5906.0 0.9880
+5908.0 0.9877
+5910.0 0.9874
+5912.0 0.9873
+5914.0 0.9873
+5916.0 0.9872
+5918.0 0.9872
+5920.0 0.9871
+5922.0 0.9873
+5924.0 0.9874
+5926.0 0.9875
+5928.0 0.9877
+5930.0 0.9878
+5932.0 0.9880
+5934.0 0.9883
+5936.0 0.9885
+5938.0 0.9887
+5940.0 0.9889
+5942.0 0.9890
+5944.0 0.9890
+5946.0 0.9891
+5948.0 0.9891
+5950.0 0.9892
+5952.0 0.9892
+5954.0 0.9892
+5956.0 0.9893
+5958.0 0.9893
+5960.0 0.9893
+5962.0 0.9891
+5964.0 0.9888
+5966.0 0.9885
+5968.0 0.9882
+5970.0 0.9879
+5972.0 0.9873
+5974.0 0.9868
+5976.0 0.9862
+5978.0 0.9856
+5980.0 0.9850
+5982.0 0.9847
+5984.0 0.9844
+5986.0 0.9841
+5988.0 0.9838
+5990.0 0.9835
+5992.0 0.9834
+5994.0 0.9833
+5996.0 0.9833
+5998.0 0.9832
+6000.0 0.9831
+6002.0 0.9832
+6004.0 0.9833
+6006.0 0.9834
+6008.0 0.9835
+6010.0 0.9836
+6012.0 0.9837
+6014.0 0.9838
+6016.0 0.9839
+6018.0 0.9840
+6020.0 0.9841
+6022.0 0.9847
+6024.0 0.9854
+6026.0 0.9861
+6028.0 0.9867
+6030.0 0.9874
+6032.0 0.9875
+6034.0 0.9876
+6036.0 0.9878
+6038.0 0.9879
+6040.0 0.9880
+6042.0 0.9885
+6044.0 0.9889
+6046.0 0.9894
+6048.0 0.9898
+6050.0 0.9903
+6052.0 0.9900
+6054.0 0.9897
+6056.0 0.9895
+6058.0 0.9892
+6060.0 0.9890
+6062.0 0.9889
+6064.0 0.9888
+6066.0 0.9887
+6068.0 0.9885
+6070.0 0.9884
+6072.0 0.9885
+6074.0 0.9885
+6076.0 0.9885
+6078.0 0.9885
+6080.0 0.9886
+6082.0 0.9883
+6084.0 0.9880
+6086.0 0.9877
+6088.0 0.9874
+6090.0 0.9871
+6092.0 0.9870
+6094.0 0.9869
+6096.0 0.9868
+6098.0 0.9867
+6100.0 0.9867
+6102.0 0.9870
+6104.0 0.9874
+6106.0 0.9878
+6108.0 0.9882
+6110.0 0.9886
+6112.0 0.9886
+6114.0 0.9887
+6116.0 0.9888
+6118.0 0.9888
+6120.0 0.9889
+6122.0 0.9889
+6124.0 0.9890
+6126.0 0.9891
+6128.0 0.9891
+6130.0 0.9892
+6132.0 0.9895
+6134.0 0.9898
+6136.0 0.9901
+6138.0 0.9904
+6140.0 0.9907
+6142.0 0.9907
+6144.0 0.9906
+6146.0 0.9906
+6148.0 0.9906
+6150.0 0.9906
+6152.0 0.9901
+6154.0 0.9896
+6156.0 0.9891
+6158.0 0.9886
+6160.0 0.9882
+6162.0 0.9879
+6164.0 0.9876
+6166.0 0.9874
+6168.0 0.9871
+6170.0 0.9868
+6172.0 0.9868
+6174.0 0.9868
+6176.0 0.9868
+6178.0 0.9868
+6180.0 0.9867
+6182.0 0.9865
+6184.0 0.9863
+6186.0 0.9861
+6188.0 0.9858
+6190.0 0.9856
+6192.0 0.9856
+6194.0 0.9856
+6196.0 0.9857
+6198.0 0.9857
+6200.0 0.9857
+6202.0 0.9861
+6204.0 0.9865
+6206.0 0.9869
+6208.0 0.9872
+6210.0 0.9876
+6212.0 0.9879
+6214.0 0.9882
+6216.0 0.9885
+6218.0 0.9888
+6220.0 0.9891
+6222.0 0.9894
+6224.0 0.9897
+6226.0 0.9899
+6228.0 0.9902
+6230.0 0.9905
+6232.0 0.9903
+6234.0 0.9901
+6236.0 0.9899
+6238.0 0.9897
+6240.0 0.9895
+6242.0 0.9897
+6244.0 0.9898
+6246.0 0.9900
+6248.0 0.9901
+6250.0 0.9903
+6252.0 0.9902
+6254.0 0.9900
+6256.0 0.9899
+6258.0 0.9897
+6260.0 0.9895
+6262.0 0.9894
+6264.0 0.9892
+6266.0 0.9891
+6268.0 0.9889
+6270.0 0.9888
+6272.0 0.9886
+6274.0 0.9884
+6276.0 0.9882
+6278.0 0.9881
+6280.0 0.9879
+6282.0 0.9878
+6284.0 0.9877
+6286.0 0.9876
+6288.0 0.9875
+6290.0 0.9874
+6292.0 0.9874
+6294.0 0.9875
+6296.0 0.9876
+6298.0 0.9876
+6300.0 0.9877
+6302.0 0.9880
+6304.0 0.9884
+6306.0 0.9888
+6308.0 0.9892
+6310.0 0.9895
+6312.0 0.9897
+6314.0 0.9898
+6316.0 0.9899
+6318.0 0.9901
+6320.0 0.9902
+6322.0 0.9901
+6324.0 0.9900
+6326.0 0.9899
+6328.0 0.9898
+6330.0 0.9897
+6332.0 0.9896
+6334.0 0.9894
+6336.0 0.9893
+6338.0 0.9891
+6340.0 0.9889
+6342.0 0.9888
+6344.0 0.9886
+6346.0 0.9885
+6348.0 0.9883
+6350.0 0.9881
+6352.0 0.9880
+6354.0 0.9879
+6356.0 0.9878
+6358.0 0.9877
+6360.0 0.9876
+6362.0 0.9875
+6364.0 0.9874
+6366.0 0.9873
+6368.0 0.9872
+6370.0 0.9870
+6372.0 0.9872
+6374.0 0.9873
+6376.0 0.9874
+6378.0 0.9875
+6380.0 0.9876
+6382.0 0.9876
+6384.0 0.9876
+6386.0 0.9876
+6388.0 0.9876
+6390.0 0.9876
+6392.0 0.9875
+6394.0 0.9873
+6396.0 0.9871
+6398.0 0.9870
+6400.0 0.9868
+6402.0 0.9873
+6404.0 0.9878
+6406.0 0.9882
+6408.0 0.9887
+6410.0 0.9892
+6412.0 0.9890
+6414.0 0.9889
+6416.0 0.9888
+6418.0 0.9886
+6420.0 0.9885
+6422.0 0.9884
+6424.0 0.9884
+6426.0 0.9883
+6428.0 0.9882
+6430.0 0.9881
+6432.0 0.9883
+6434.0 0.9884
+6436.0 0.9886
+6438.0 0.9887
+6440.0 0.9889
+6442.0 0.9887
+6444.0 0.9885
+6446.0 0.9883
+6448.0 0.9881
+6450.0 0.9879
+6452.0 0.9882
+6454.0 0.9885
+6456.0 0.9888
+6458.0 0.9892
+6460.0 0.9895
+6462.0 0.9891
+6464.0 0.9888
+6466.0 0.9885
+6468.0 0.9881
+6470.0 0.9878
+6472.0 0.9881
+6474.0 0.9884
+6476.0 0.9887
+6478.0 0.9890
+6480.0 0.9893
+6482.0 0.9894
+6484.0 0.9896
+6486.0 0.9898
+6488.0 0.9899
+6490.0 0.9901
+6492.0 0.9903
+6494.0 0.9905
+6496.0 0.9907
+6498.0 0.9909
+6500.0 0.9911
+6502.0 0.9911
+6504.0 0.9911
+6506.0 0.9910
+6508.0 0.9910
+6510.0 0.9910
+6512.0 0.9907
+6514.0 0.9904
+6516.0 0.9900
+6518.0 0.9897
+6520.0 0.9894
+6522.0 0.9897
+6524.0 0.9900
+6526.0 0.9902
+6528.0 0.9905
+6530.0 0.9908
+6532.0 0.9905
+6534.0 0.9902
+6536.0 0.9899
+6538.0 0.9896
+6540.0 0.9893
+6542.0 0.9891
+6544.0 0.9888
+6546.0 0.9886
+6548.0 0.9883
+6550.0 0.9881
+6552.0 0.9881
+6554.0 0.9881
+6556.0 0.9882
+6558.0 0.9882
+6560.0 0.9882
+6562.0 0.9882
+6564.0 0.9882
+6566.0 0.9882
+6568.0 0.9882
+6570.0 0.9882
+6572.0 0.9883
+6574.0 0.9885
+6576.0 0.9886
+6578.0 0.9888
+6580.0 0.9890
+6582.0 0.9889
+6584.0 0.9888
+6586.0 0.9888
+6588.0 0.9887
+6590.0 0.9886
+6592.0 0.9888
+6594.0 0.9889
+6596.0 0.9890
+6598.0 0.9892
+6600.0 0.9893
+6602.0 0.9895
+6604.0 0.9896
+6606.0 0.9897
+6608.0 0.9899
+6610.0 0.9900
+6612.0 0.9902
+6614.0 0.9904
+6616.0 0.9905
+6618.0 0.9907
+6620.0 0.9909
+6622.0 0.9905
+6624.0 0.9901
+6626.0 0.9897
+6628.0 0.9893
+6630.0 0.9889
+6632.0 0.9888
+6634.0 0.9886
+6636.0 0.9884
+6638.0 0.9882
+6640.0 0.9881
+6642.0 0.9880
+6644.0 0.9880
+6646.0 0.9879
+6648.0 0.9879
+6650.0 0.9879
+6652.0 0.9878
+6654.0 0.9877
+6656.0 0.9877
+6658.0 0.9876
+6660.0 0.9876
+6662.0 0.9878
+6664.0 0.9880
+6666.0 0.9883
+6668.0 0.9885
+6670.0 0.9888
+6672.0 0.9888
+6674.0 0.9889
+6676.0 0.9889
+6678.0 0.9889
+6680.0 0.9890
+6682.0 0.9895
+6684.0 0.9900
+6686.0 0.9906
+6688.0 0.9911
+6690.0 0.9916
+6692.0 0.9916
+6694.0 0.9916
+6696.0 0.9916
+6698.0 0.9916
+6700.0 0.9916
+6702.0 0.9918
+6704.0 0.9920
+6706.0 0.9922
+6708.0 0.9924
+6710.0 0.9926
+6712.0 0.9926
+6714.0 0.9925
+6716.0 0.9925
+6718.0 0.9925
+6720.0 0.9925
+6722.0 0.9922
+6724.0 0.9920
+6726.0 0.9917
+6728.0 0.9915
+6730.0 0.9912
+6732.0 0.9914
+6734.0 0.9916
+6736.0 0.9918
+6738.0 0.9920
+6740.0 0.9922
+6742.0 0.9920
+6744.0 0.9917
+6746.0 0.9915
+6748.0 0.9913
+6750.0 0.9911
+6752.0 0.9903
+6754.0 0.9896
+6756.0 0.9889
+6758.0 0.9881
+6760.0 0.9874
+6762.0 0.9875
+6764.0 0.9876
+6766.0 0.9877
+6768.0 0.9878
+6770.0 0.9879
+6772.0 0.9880
+6774.0 0.9881
+6776.0 0.9882
+6778.0 0.9883
+6780.0 0.9884
+6782.0 0.9887
+6784.0 0.9891
+6786.0 0.9894
+6788.0 0.9898
+6790.0 0.9901
+6792.0 0.9901
+6794.0 0.9900
+6796.0 0.9899
+6798.0 0.9898
+6800.0 0.9897
+6802.0 0.9901
+6804.0 0.9904
+6806.0 0.9908
+6808.0 0.9912
+6810.0 0.9915
+6812.0 0.9917
+6814.0 0.9920
+6816.0 0.9922
+6818.0 0.9924
+6820.0 0.9926
+6822.0 0.9927
+6824.0 0.9929
+6826.0 0.9930
+6828.0 0.9931
+6830.0 0.9932
+6832.0 0.9931
+6834.0 0.9929
+6836.0 0.9927
+6838.0 0.9926
+6840.0 0.9924
+6842.0 0.9923
+6844.0 0.9923
+6846.0 0.9922
+6848.0 0.9921
+6850.0 0.9921
+6852.0 0.9917
+6854.0 0.9912
+6856.0 0.9908
+6858.0 0.9904
+6860.0 0.9900
+6862.0 0.9901
+6864.0 0.9902
+6866.0 0.9903
+6868.0 0.9904
+6870.0 0.9906
+6872.0 0.9901
+6874.0 0.9897
+6876.0 0.9893
+6878.0 0.9889
+6880.0 0.9884
+6882.0 0.9882
+6884.0 0.9880
+6886.0 0.9878
+6888.0 0.9876
+6890.0 0.9874
+6892.0 0.9874
+6894.0 0.9873
+6896.0 0.9873
+6898.0 0.9873
+6900.0 0.9872
+6902.0 0.9874
+6904.0 0.9875
+6906.0 0.9876
+6908.0 0.9878
+6910.0 0.9879
+6912.0 0.9883
+6914.0 0.9887
+6916.0 0.9890
+6918.0 0.9894
+6920.0 0.9898
+6922.0 0.9902
+6924.0 0.9906
+6926.0 0.9910
+6928.0 0.9915
+6930.0 0.9919
+6932.0 0.9921
+6934.0 0.9924
+6936.0 0.9926
+6938.0 0.9929
+6940.0 0.9931
+6942.0 0.9930
+6944.0 0.9929
+6946.0 0.9927
+6948.0 0.9926
+6950.0 0.9925
+6952.0 0.9928
+6954.0 0.9931
+6956.0 0.9935
+6958.0 0.9938
+6960.0 0.9941
+6962.0 0.9937
+6964.0 0.9934
+6966.0 0.9930
+6968.0 0.9926
+6970.0 0.9922
+6972.0 0.9918
+6974.0 0.9914
+6976.0 0.9910
+6978.0 0.9905
+6980.0 0.9901
+6982.0 0.9901
+6984.0 0.9901
+6986.0 0.9900
+6988.0 0.9900
+6990.0 0.9900
+6992.0 0.9895
+6994.0 0.9891
+6996.0 0.9887
+6998.0 0.9882
+7000.0 0.9878
+7002.0 0.9877
+7004.0 0.9876
+7006.0 0.9874
+7008.0 0.9873
+7010.0 0.9872
+7012.0 0.9873
+7014.0 0.9874
+7016.0 0.9875
+7018.0 0.9876
+7020.0 0.9877
+7022.0 0.9877
+7024.0 0.9877
+7026.0 0.9877
+7028.0 0.9877
+7030.0 0.9877
+7032.0 0.9881
+7034.0 0.9886
+7036.0 0.9890
+7038.0 0.9894
+7040.0 0.9898
+7042.0 0.9906
+7044.0 0.9913
+7046.0 0.9920
+7048.0 0.9927
+7050.0 0.9934
+7052.0 0.9933
+7054.0 0.9932
+7056.0 0.9931
+7058.0 0.9930
+7060.0 0.9929
+7062.0 0.9932
+7064.0 0.9934
+7066.0 0.9937
+7068.0 0.9940
+7070.0 0.9943
+7072.0 0.9942
+7074.0 0.9941
+7076.0 0.9941
+7078.0 0.9940
+7080.0 0.9940
+7082.0 0.9939
+7084.0 0.9938
+7086.0 0.9938
+7088.0 0.9937
+7090.0 0.9936
+7092.0 0.9931
+7094.0 0.9927
+7096.0 0.9922
+7098.0 0.9917
+7100.0 0.9912
+7102.0 0.9911
+7104.0 0.9910
+7106.0 0.9908
+7108.0 0.9907
+7110.0 0.9906
+7112.0 0.9903
+7114.0 0.9899
+7116.0 0.9896
+7118.0 0.9893
+7120.0 0.9890
+7122.0 0.9888
+7124.0 0.9887
+7126.0 0.9886
+7128.0 0.9885
+7130.0 0.9883
+7132.0 0.9884
+7134.0 0.9885
+7136.0 0.9885
+7138.0 0.9886
+7140.0 0.9886
+7142.0 0.9888
+7144.0 0.9890
+7146.0 0.9892
+7148.0 0.9894
+7150.0 0.9896
+7152.0 0.9899
+7154.0 0.9902
+7156.0 0.9905
+7158.0 0.9907
+7160.0 0.9910
+7162.0 0.9913
+7164.0 0.9916
+7166.0 0.9919
+7168.0 0.9922
+7170.0 0.9925
+7172.0 0.9927
+7174.0 0.9929
+7176.0 0.9932
+7178.0 0.9934
+7180.0 0.9937
+7182.0 0.9938
+7184.0 0.9940
+7186.0 0.9941
+7188.0 0.9943
+7190.0 0.9944
+7192.0 0.9943
+7194.0 0.9942
+7196.0 0.9941
+7198.0 0.9940
+7200.0 0.9939
+7202.0 0.9938
+7204.0 0.9937
+7206.0 0.9936
+7208.0 0.9935
+7210.0 0.9934
+7212.0 0.9932
+7214.0 0.9929
+7216.0 0.9926
+7218.0 0.9924
+7220.0 0.9921
+7222.0 0.9917
+7224.0 0.9913
+7226.0 0.9909
+7228.0 0.9905
+7230.0 0.9901
+7232.0 0.9897
+7234.0 0.9893
+7236.0 0.9890
+7238.0 0.9886
+7240.0 0.9882
+7242.0 0.9882
+7244.0 0.9882
+7246.0 0.9882
+7248.0 0.9882
+7250.0 0.9881
+7252.0 0.9879
+7254.0 0.9877
+7256.0 0.9875
+7258.0 0.9873
+7260.0 0.9871
+7262.0 0.9872
+7264.0 0.9874
+7266.0 0.9876
+7268.0 0.9877
+7270.0 0.9879
+7272.0 0.9877
+7274.0 0.9875
+7276.0 0.9872
+7278.0 0.9870
+7280.0 0.9868
+7282.0 0.9873
+7284.0 0.9878
+7286.0 0.9883
+7288.0 0.9887
+7290.0 0.9892
+7292.0 0.9898
+7294.0 0.9904
+7296.0 0.9909
+7298.0 0.9915
+7300.0 0.9920
+7302.0 0.9923
+7304.0 0.9927
+7306.0 0.9930
+7308.0 0.9933
+7310.0 0.9936
+7312.0 0.9935
+7314.0 0.9934
+7316.0 0.9933
+7318.0 0.9931
+7320.0 0.9930
+7322.0 0.9929
+7324.0 0.9927
+7326.0 0.9925
+7328.0 0.9923
+7330.0 0.9922
+7332.0 0.9921
+7334.0 0.9920
+7336.0 0.9919
+7338.0 0.9918
+7340.0 0.9917
+7342.0 0.9916
+7344.0 0.9915
+7346.0 0.9914
+7348.0 0.9913
+7350.0 0.9912
+7352.0 0.9906
+7354.0 0.9899
+7356.0 0.9893
+7358.0 0.9887
+7360.0 0.9881
+7362.0 0.9880
+7364.0 0.9878
+7366.0 0.9877
+7368.0 0.9875
+7370.0 0.9874
+7372.0 0.9872
+7374.0 0.9870
+7376.0 0.9868
+7378.0 0.9866
+7380.0 0.9864
+7382.0 0.9866
+7384.0 0.9868
+7386.0 0.9869
+7388.0 0.9871
+7390.0 0.9872
+7392.0 0.9875
+7394.0 0.9878
+7396.0 0.9880
+7398.0 0.9883
+7400.0 0.9886
+7402.0 0.9888
+7404.0 0.9889
+7406.0 0.9891
+7408.0 0.9893
+7410.0 0.9894
+7412.0 0.9896
+7414.0 0.9898
+7416.0 0.9900
+7418.0 0.9902
+7420.0 0.9904
+7422.0 0.9908
+7424.0 0.9912
+7426.0 0.9916
+7428.0 0.9920
+7430.0 0.9924
+7432.0 0.9928
+7434.0 0.9931
+7436.0 0.9934
+7438.0 0.9937
+7440.0 0.9941
+7442.0 0.9938
+7444.0 0.9935
+7446.0 0.9933
+7448.0 0.9930
+7450.0 0.9927
+7452.0 0.9927
+7454.0 0.9927
+7456.0 0.9927
+7458.0 0.9927
+7460.0 0.9927
+7462.0 0.9926
+7464.0 0.9924
+7466.0 0.9922
+7468.0 0.9920
+7470.0 0.9919
+7472.0 0.9915
+7474.0 0.9912
+7476.0 0.9909
+7478.0 0.9905
+7480.0 0.9902
+7482.0 0.9895
+7484.0 0.9888
+7486.0 0.9880
+7488.0 0.9873
+7490.0 0.9866
+7492.0 0.9863
+7494.0 0.9859
+7496.0 0.9856
+7498.0 0.9852
+7500.0 0.9849
+7502.0 0.9848
+7504.0 0.9847
+7506.0 0.9846
+7508.0 0.9845
+7510.0 0.9844
+7512.0 0.9842
+7514.0 0.9841
+7516.0 0.9839
+7518.0 0.9838
+7520.0 0.9836
+7522.0 0.9837
+7524.0 0.9838
+7526.0 0.9839
+7528.0 0.9840
+7530.0 0.9841
+7532.0 0.9845
+7534.0 0.9848
+7536.0 0.9852
+7538.0 0.9856
+7540.0 0.9859
+7542.0 0.9862
+7544.0 0.9864
+7546.0 0.9867
+7548.0 0.9869
+7550.0 0.9872
+7552.0 0.9877
+7554.0 0.9883
+7556.0 0.9888
+7558.0 0.9893
+7560.0 0.9899
+7562.0 0.9904
+7564.0 0.9910
+7566.0 0.9916
+7568.0 0.9922
+7570.0 0.9927
+7572.0 0.9927
+7574.0 0.9927
+7576.0 0.9927
+7578.0 0.9927
+7580.0 0.9927
+7582.0 0.9925
+7584.0 0.9924
+7586.0 0.9923
+7588.0 0.9922
+7590.0 0.9920
+7592.0 0.9924
+7594.0 0.9927
+7596.0 0.9931
+7598.0 0.9934
+7600.0 0.9938
+7602.0 0.9934
+7604.0 0.9930
+7606.0 0.9926
+7608.0 0.9923
+7610.0 0.9919
+7612.0 0.9917
+7614.0 0.9915
+7616.0 0.9914
+7618.0 0.9912
+7620.0 0.9910
+7622.0 0.9911
+7624.0 0.9912
+7626.0 0.9913
+7628.0 0.9914
+7630.0 0.9915
+7632.0 0.9914
+7634.0 0.9912
+7636.0 0.9911
+7638.0 0.9910
+7640.0 0.9909
+7642.0 0.9907
+7644.0 0.9905
+7646.0 0.9902
+7648.0 0.9900
+7650.0 0.9898
+7652.0 0.9899
+7654.0 0.9900
+7656.0 0.9901
+7658.0 0.9901
+7660.0 0.9902
+7662.0 0.9901
+7664.0 0.9900
+7666.0 0.9899
+7668.0 0.9898
+7670.0 0.9897
+7672.0 0.9901
+7674.0 0.9904
+7676.0 0.9908
+7678.0 0.9911
+7680.0 0.9915
+7682.0 0.9917
+7684.0 0.9919
+7686.0 0.9921
+7688.0 0.9923
+7690.0 0.9925
+7692.0 0.9926
+7694.0 0.9928
+7696.0 0.9930
+7698.0 0.9932
+7700.0 0.9934
+7702.0 0.9935
+7704.0 0.9936
+7706.0 0.9937
+7708.0 0.9938
+7710.0 0.9939
+7712.0 0.9938
+7714.0 0.9936
+7716.0 0.9935
+7718.0 0.9934
+7720.0 0.9932
+7722.0 0.9931
+7724.0 0.9929
+7726.0 0.9927
+7728.0 0.9925
+7730.0 0.9923
+7732.0 0.9920
+7734.0 0.9917
+7736.0 0.9913
+7738.0 0.9910
+7740.0 0.9906
+7742.0 0.9904
+7744.0 0.9901
+7746.0 0.9898
+7748.0 0.9895
+7750.0 0.9892
+7752.0 0.9889
+7754.0 0.9887
+7756.0 0.9885
+7758.0 0.9882
+7760.0 0.9880
+7762.0 0.9879
+7764.0 0.9879
+7766.0 0.9878
+7768.0 0.9878
+7770.0 0.9877
+7772.0 0.9876
+7774.0 0.9875
+7776.0 0.9873
+7778.0 0.9872
+7780.0 0.9871
+7782.0 0.9868
+7784.0 0.9864
+7786.0 0.9861
+7788.0 0.9858
+7790.0 0.9855
+7792.0 0.9859
+7794.0 0.9864
+7796.0 0.9868
+7798.0 0.9873
+7800.0 0.9877
+7802.0 0.9876
+7804.0 0.9875
+7806.0 0.9874
+7808.0 0.9873
+7810.0 0.9872
+7812.0 0.9876
+7814.0 0.9881
+7816.0 0.9886
+7818.0 0.9891
+7820.0 0.9896
+7822.0 0.9897
+7824.0 0.9898
+7826.0 0.9899
+7828.0 0.9901
+7830.0 0.9902
+7832.0 0.9899
+7834.0 0.9897
+7836.0 0.9894
+7838.0 0.9891
+7840.0 0.9888
+7842.0 0.9891
+7844.0 0.9894
+7846.0 0.9897
+7848.0 0.9900
+7850.0 0.9903
+7852.0 0.9898
+7854.0 0.9893
+7856.0 0.9888
+7858.0 0.9883
+7860.0 0.9878
+7862.0 0.9877
+7864.0 0.9875
+7866.0 0.9874
+7868.0 0.9873
+7870.0 0.9872
+7872.0 0.9871
+7874.0 0.9870
+7876.0 0.9869
+7878.0 0.9868
+7880.0 0.9867
+7882.0 0.9869
+7884.0 0.9871
+7886.0 0.9873
+7888.0 0.9875
+7890.0 0.9877
+7892.0 0.9875
+7894.0 0.9873
+7896.0 0.9871
+7898.0 0.9869
+7900.0 0.9867
+7902.0 0.9867
+7904.0 0.9867
+7906.0 0.9866
+7908.0 0.9866
+7910.0 0.9866
+7912.0 0.9866
+7914.0 0.9865
+7916.0 0.9865
+7918.0 0.9865
+7920.0 0.9865
+7922.0 0.9871
+7924.0 0.9877
+7926.0 0.9883
+7928.0 0.9889
+7930.0 0.9896
+7932.0 0.9898
+7934.0 0.9900
+7936.0 0.9903
+7938.0 0.9905
+7940.0 0.9908
+7942.0 0.9910
+7944.0 0.9913
+7946.0 0.9916
+7948.0 0.9918
+7950.0 0.9921
+7952.0 0.9921
+7954.0 0.9920
+7956.0 0.9920
+7958.0 0.9919
+7960.0 0.9919
+7962.0 0.9914
+7964.0 0.9910
+7966.0 0.9905
+7968.0 0.9900
+7970.0 0.9896
+7972.0 0.9895
+7974.0 0.9895
+7976.0 0.9894
+7978.0 0.9893
+7980.0 0.9893
+7982.0 0.9889
+7984.0 0.9885
+7986.0 0.9881
+7988.0 0.9876
+7990.0 0.9872
+7992.0 0.9869
+7994.0 0.9866
+7996.0 0.9863
+7998.0 0.9860
+8000.0 0.9857
+8002.0 0.9856
+8004.0 0.9855
+8006.0 0.9854
+8008.0 0.9853
+8010.0 0.9852
+8012.0 0.9851
+8014.0 0.9850
+8016.0 0.9849
+8018.0 0.9848
+8020.0 0.9847
+8022.0 0.9847
+8024.0 0.9848
+8026.0 0.9848
+8028.0 0.9849
+8030.0 0.9849
+8032.0 0.9847
+8034.0 0.9845
+8036.0 0.9843
+8038.0 0.9841
+8040.0 0.9839
+8042.0 0.9842
+8044.0 0.9845
+8046.0 0.9848
+8048.0 0.9851
+8050.0 0.9854
+8052.0 0.9855
+8054.0 0.9856
+8056.0 0.9858
+8058.0 0.9859
+8060.0 0.9860
+8062.0 0.9861
+8064.0 0.9861
+8066.0 0.9862
+8068.0 0.9863
+8070.0 0.9863
+8072.0 0.9865
+8074.0 0.9867
+8076.0 0.9868
+8078.0 0.9870
+8080.0 0.9872
+8082.0 0.9870
+8084.0 0.9868
+8086.0 0.9867
+8088.0 0.9865
+8090.0 0.9863
+8092.0 0.9858
+8094.0 0.9852
+8096.0 0.9847
+8098.0 0.9841
+8100.0 0.9836
+8102.0 0.9822
+8104.0 0.9808
+8106.0 0.9794
+8108.0 0.9780
+8110.0 0.9766
+8112.0 0.9736
+8114.0 0.9705
+8116.0 0.9675
+8118.0 0.9644
+8120.0 0.9614
+8122.0 0.9550
+8124.0 0.9486
+8126.0 0.9423
+8128.0 0.9359
+8130.0 0.9295
+8132.0 0.9192
+8134.0 0.9089
+8136.0 0.8985
+8138.0 0.8882
+8140.0 0.8779
+8142.0 0.8627
+8144.0 0.8476
+8146.0 0.8324
+8148.0 0.8173
+8150.0 0.8021
+8152.0 0.7824
+8154.0 0.7626
+8156.0 0.7429
+8158.0 0.7231
+8160.0 0.7034
+8162.0 0.6806
+8164.0 0.6578
+8166.0 0.6351
+8168.0 0.6123
+8170.0 0.5896
+8172.0 0.5663
+8174.0 0.5430
+8176.0 0.5197
+8178.0 0.4964
+8180.0 0.4731
+8182.0 0.4515
+8184.0 0.4299
+8186.0 0.4082
+8188.0 0.3866
+8190.0 0.3650
+8192.0 0.3466
+8194.0 0.3281
+8196.0 0.3097
+8198.0 0.2913
+8200.0 0.2729
+8202.0 0.2583
+8204.0 0.2437
+8206.0 0.2291
+8208.0 0.2145
+8210.0 0.1999
+8212.0 0.1889
+8214.0 0.1779
+8216.0 0.1669
+8218.0 0.1560
+8220.0 0.1450
+8222.0 0.1369
+8224.0 0.1289
+8226.0 0.1208
+8228.0 0.1128
+8230.0 0.1047
+8232.0 0.0989
+8234.0 0.0932
+8236.0 0.0874
+8238.0 0.0816
+8240.0 0.0758
+8242.0 0.0717
+8244.0 0.0675
+8246.0 0.0634
+8248.0 0.0593
+8250.0 0.0551
+8252.0 0.0522
+8254.0 0.0493
+8256.0 0.0463
+8258.0 0.0434
+8260.0 0.0405
+8262.0 0.0383
+8264.0 0.0362
+8266.0 0.0341
+8268.0 0.0320
+8270.0 0.0298
+8272.0 0.0283
+8274.0 0.0268
+8276.0 0.0253
+8278.0 0.0237
+8280.0 0.0222
+8282.0 0.0211
+8284.0 0.0200
+8286.0 0.0189
+8288.0 0.0178
+8290.0 0.0166
+8292.0 0.0158
+8294.0 0.0150
+8296.0 0.0142
+8298.0 0.0134
+8300.0 0.0126
+8302.0 0.0120
+8304.0 0.0114
+8306.0 0.0108
+8308.0 0.0102
+8310.0 0.0096
+8312.0 0.0091
+8314.0 0.0087
+8316.0 0.0083
+8318.0 0.0078
+8320.0 0.0074
+8322.0 0.0071
+8324.0 0.0067
+8326.0 0.0064
+8328.0 0.0060
+8330.0 0.0057
+8332.0 0.0054
+8334.0 0.0052
+8336.0 0.0050
+8338.0 0.0047
+8340.0 0.0045
+8342.0 0.0043
+8344.0 0.0041
+8346.0 0.0039
+8348.0 0.0037
+8350.0 0.0035
+8352.0 0.0034
+8354.0 0.0032
+8356.0 0.0031
+8358.0 0.0029
+8360.0 0.0028
+8362.0 0.0027
+8364.0 0.0026
+8366.0 0.0025
+8368.0 0.0024
+8370.0 0.0023
+8372.0 0.0022
+8374.0 0.0021
+8376.0 0.0020
+8378.0 0.0019
+8380.0 0.0019
+8382.0 0.0018
+8384.0 0.0017
+8386.0 0.0017
+8388.0 0.0016
+8390.0 0.0015
+8392.0 0.0015
+8394.0 0.0014
+8396.0 0.0014
+8398.0 0.0013
+8400.0 0.0012
+8402.0 0.0012
+8404.0 0.0012
+8406.0 0.0012
+8408.0 0.0011
+8410.0 0.0011
+8412.0 0.0011
+8414.0 0.0010
+8416.0 0.0010
+8418.0 0.0009
+8420.0 0.0009
+8422.0 0.0009
+8424.0 0.0008
+8426.0 0.0008
+8428.0 0.0008
+8430.0 0.0008
+8432.0 0.0007
+8434.0 0.0007
+8436.0 0.0007
+8438.0 0.0006
+8440.0 0.0006
+8442.0 0.0006
+8444.0 0.0006
+8446.0 0.0005
+8448.0 0.0005
+8450.0 0.0005
+8452.0 0.0005
+8454.0 0.0005
+8456.0 0.0005
+8458.0 0.0005
+8460.0 0.0005
+8462.0 0.0005
+8464.0 0.0005
+8466.0 0.0005
+8468.0 0.0005
+8470.0 0.0005
+8472.0 0.0005
+8474.0 0.0005
+8476.0 0.0004
+8478.0 0.0004
+8480.0 0.0004
+8482.0 0.0004
+8484.0 0.0004
+8486.0 0.0004
+8488.0 0.0005
+8490.0 0.0005
+8492.0 0.0005
+8494.0 0.0004
+8496.0 0.0004
+8498.0 0.0004
+8500.0 0.0003
+8502.0 0.0003
+8504.0 0.0003
+8506.0 0.0003
+8508.0 0.0003
+8510.0 0.0003
+8512.0 0.0002
+8514.0 0.0002
+8516.0 0.0002
+8518.0 0.0002
+8520.0 0.0002
+8522.0 0.0002
+8524.0 0.0002
+8526.0 0.0002
+8528.0 0.0002
+8530.0 0.0002
+8532.0 0.0002
+8534.0 0.0002
+8536.0 0.0002
+8538.0 0.0002
+8540.0 0.0002
+8542.0 0.0002
+8544.0 0.0001
+8546.0 0.0001
+8548.0 0.0001
+8550.0 0.0001
+8552.0 0.0001
+8554.0 0.0001
+8556.0 0.0001
+8558.0 0.0001
+8560.0 0.0001
+8562.0 0.0001
+8564.0 0.0001
+8566.0 0.0001
+8568.0 0.0001
+8570.0 0.0001
+8572.0 0.0001
+8574.0 0.0001
+8576.0 0.0001
+8578.0 0.0001
+8580.0 0.0001
+8582.0 0.0001
+8584.0 0.0001
+8586.0 0.0001
+8588.0 0.0001
+8590.0 0.0001
+8592.0 0.0001
+8594.0 0.0001
+8596.0 0.0001
+8598.0 0.0001
+8600.0 0.0001
+8602.0 0.0001
+8604.0 0.0001
+8606.0 0.0001
+8608.0 0.0001
+8610.0 0.0001
+8612.0 0.0001
+8614.0 0.0001
+8616.0 0.0001
+8618.0 0.0001
+8620.0 0.0001
+8622.0 0.0001
+8624.0 0.0001
+8626.0 0.0001
+8628.0 0.0001
+8630.0 0.0001
+8632.0 0.0001
+8634.0 0.0001
+8636.0 0.0001
+8638.0 0.0001
+8640.0 0.0001
+8642.0 0.0001
+8644.0 0.0001
+8646.0 0.0001
+8648.0 0.0001
+8650.0 0.0001
+8652.0 0.0001
+8654.0 0.0001
+8656.0 0.0001
+8658.0 0.0001
+8660.0 0.0001
+8662.0 0.0001
+8664.0 0.0001
+8666.0 0.0001
+8668.0 0.0001
+8670.0 0.0001
+8672.0 0.0001
+8674.0 0.0001
+8676.0 0.0001
+8678.0 0.0001
+8680.0 0.0001
+8682.0 0.0001
+8684.0 0.0001
+8686.0 0.0001
+8688.0 0.0001
+8690.0 0.0001
+8692.0 0.0001
+8694.0 0.0001
+8696.0 0.0001
+8698.0 0.0001
+8700.0 0.0001
+8702.0 0.0001
+8704.0 0.0001
+8706.0 0.0001
+8708.0 0.0001
+8710.0 0.0001
+8712.0 0.0001
+8714.0 0.0001
+8716.0 0.0001
+8718.0 0.0001
+8720.0 0.0001
+8722.0 0.0001
+8724.0 0.0001
+8726.0 0.0001
+8728.0 0.0001
+8730.0 0.0001
+8732.0 0.0001
+8734.0 0.0001
+8736.0 0.0001
+8738.0 0.0001
+8740.0 0.0001
+8742.0 0.0001
+8744.0 0.0001
+8746.0 0.0000
+8748.0 0.0000
+8750.0 0.0000
+8752.0 0.0000
+8754.0 0.0001
+8756.0 0.0001
+8758.0 0.0001
+8760.0 0.0001
+8762.0 0.0001
+8764.0 0.0001
+8766.0 0.0001
+8768.0 0.0001
+8770.0 0.0001
+8772.0 0.0001
+8774.0 0.0001
+8776.0 0.0001
+8778.0 0.0001
+8780.0 0.0001
+8782.0 0.0001
+8784.0 0.0001
+8786.0 0.0001
+8788.0 0.0001
+8790.0 0.0001
+8792.0 0.0001
+8794.0 0.0001
+8796.0 0.0001
+8798.0 0.0001
+8800.0 0.0000
+8802.0 0.0000
+8804.0 0.0000
+8806.0 0.0000
+8808.0 0.0000
+8810.0 0.0001
+8812.0 0.0001
+8814.0 0.0001
+8816.0 0.0001
+8818.0 0.0001
+8820.0 0.0001
+8822.0 0.0001
+8824.0 0.0001
+8826.0 0.0000
+8828.0 0.0000
+8830.0 0.0000
+8832.0 0.0000
+8834.0 0.0000
+8836.0 0.0000
+8838.0 0.0000
+8840.0 0.0000
+8842.0 0.0000
+8844.0 0.0000
+8846.0 0.0000
+8848.0 0.0000
+8850.0 0.0001
+8852.0 0.0000
+8854.0 0.0000
+8856.0 0.0000
+8858.0 0.0000
+8860.0 0.0000
+8862.0 0.0000
+8864.0 0.0000
+8866.0 0.0000
+8868.0 0.0000
+8870.0 0.0000
+8872.0 0.0000
+8874.0 0.0000
+8876.0 0.0000
+8878.0 0.0000
+8880.0 0.0000
+8882.0 0.0000
+8884.0 0.0000
+8886.0 0.0000
+8888.0 0.0000
+8890.0 0.0000
+8892.0 0.0000
+8894.0 0.0000
+8896.0 0.0000
+8898.0 0.0000
+8900.0 0.0000
+8902.0 0.0000
+8904.0 0.0000
+8906.0 0.0000
+8908.0 0.0000
+8910.0 0.0000
+8912.0 0.0000
+8914.0 0.0000
+8916.0 0.0000
+8918.0 0.0000
+8920.0 0.0000
+8922.0 0.0000
+8924.0 0.0000
+8926.0 0.0000
+8928.0 0.0000
+8930.0 0.0000
+8932.0 0.0000
+8934.0 0.0000
+8936.0 0.0000
+8938.0 0.0000
+8940.0 0.0000
+8942.0 0.0000
+8944.0 0.0000
+8946.0 0.0000
+8948.0 0.0000
+8950.0 0.0000
+8952.0 0.0000
+8954.0 0.0000
+8956.0 0.0000
+8958.0 0.0000
+8960.0 0.0000
+8962.0 0.0000
+8964.0 0.0000
+8966.0 0.0000
+8968.0 0.0000
+8970.0 0.0000
+8972.0 0.0000
+8974.0 0.0000
+8976.0 0.0000
+8978.0 0.0000
+8980.0 0.0000
+8982.0 0.0000
+8984.0 0.0000
+8986.0 0.0000
+8988.0 0.0000
+8990.0 0.0000
+8992.0 0.0000
+8994.0 0.0000
+8996.0 0.0000
+8998.0 0.0000
+9000.0 0.0000
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB506.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB506.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB506.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB506.txt	2022-02-08 11:42:53.000000000 +0900
@@ -0,0 +1,73 @@
+# wavelength[angstrom]  transmittance
+4901.4 0.0031
+4905.6 0.0030
+4909.8 0.0030
+4913.9 0.0030
+4918.1 0.0033
+4922.2 0.0037
+4926.4 0.0034
+4930.6 0.0043
+4934.7 0.0048
+4938.9 0.0061
+4943.1 0.0077
+4947.2 0.0107
+4951.4 0.0153
+4955.6 0.0213
+4959.7 0.0305
+4963.9 0.0446
+4968.1 0.0672
+4972.2 0.1025
+4976.4 0.1468
+4980.6 0.2031
+4984.8 0.2796
+4988.9 0.3716
+4993.1 0.4723
+4997.3 0.5779
+5001.4 0.6809
+5005.6 0.7714
+5009.8 0.8432
+5014.0 0.8950
+5018.1 0.9284
+5022.3 0.9462
+5026.5 0.9532
+5030.7 0.9554
+5034.8 0.9564
+5039.0 0.9576
+5043.2 0.9594
+5047.4 0.9607
+5051.5 0.9596
+5055.7 0.9594
+5059.9 0.9599
+5064.1 0.9590
+5068.3 0.9571
+5072.4 0.9538
+5076.6 0.9476
+5080.8 0.9367
+5085.0 0.9188
+5089.2 0.8892
+5093.3 0.8452
+5097.5 0.7872
+5101.7 0.7152
+5105.9 0.6303
+5110.1 0.5356
+5114.3 0.4364
+5118.4 0.3413
+5122.6 0.2562
+5126.8 0.1852
+5131.0 0.1300
+5135.2 0.0902
+5139.4 0.0629
+5143.6 0.0440
+5147.7 0.0311
+5151.9 0.0226
+5156.1 0.0166
+5160.3 0.0121
+5164.5 0.0093
+5168.7 0.0073
+5172.9 0.0060
+5177.1 0.0049
+5181.3 0.0038
+5185.4 0.0036
+5189.6 0.0036
+5193.8 0.0034
+5198.0 0.0033
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py	2023-02-16 21:06:19.307658991 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py	2023-02-01 16:42:03.000000000 +0900
@@ -96,5 +96,8 @@
                      abstract_filter='N430', lambdaEff=430),
     FilterDefinition(physical_filter="NB0497",
                      abstract_filter='N497', lambdaEff=497),
-
+    FilterDefinition(physical_filter="EB-GRI",
+                     abstract_filter='EBgri', lambdaEff=618),
+    FilterDefinition(physical_filter="NB0506",
+                     abstract_filter='N506', lambdaEff=506),
 )
__eof__
fi

if [ $version -le 3 ]
then
patch -p7 << "__eof__"
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc-6-g681b0a8d+2/python/lsst/obs/hsc/makeTransmissionCurves.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc-6-g681b0a8d+2/python/lsst/obs/hsc/makeTransmissionCurves.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc-6-g681b0a8d+2/python/lsst/obs/hsc/makeTransmissionCurves.py	2021-11-18 14:23:39.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc-6-g681b0a8d+2/python/lsst/obs/hsc/makeTransmissionCurves.py	2023-05-15 16:30:42.521557192 +0900
@@ -49,7 +49,7 @@
         return "%s%04d" % (short[:2], num)
     f = Filter(short)
     for a in f.getAliases():
-        if a.startswith("HSC") or a.startswith("NB") or a.startswith("IB"):
+        if a.startswith("HSC") or a.startswith("NB") or a.startswith("IB") or a.startswith("EB-"):
             return a
     return short
 
__eof__
fi

if [ $version -le 4 ]
then
patch -p7 << "__eof__"
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-07-31 09:41:09.618539481 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/colorterms.py	2023-07-31 09:41:23.957691510 +0900
@@ -37,6 +37,7 @@
         'N656': Colorterm(primary="r", secondary="i", c0=0.037014, c1=-0.538947, c2=0.052489),
         'N718': Colorterm(primary="r", secondary="i", c0=-0.014742, c1=-0.787571, c2=0.237867),
         'N816': Colorterm(primary="i", secondary="z", c0=0.012676, c1=-0.660317, c2=0.055566),
+        'N872': Colorterm(primary="z", secondary="i",c0=-0.013552, c1=-0.041955, c2=0.002660),
         'N921': Colorterm(primary="z", secondary="i", c0=0.004619, c1=0.093019, c2=-0.126377),
         'N926': Colorterm(primary="z", secondary="i", c0=0.009369, c1=0.130261, c2=-0.119282),
         'N973': Colorterm(primary="z", secondary="i", c0=-0.005805, c1=0.220412, c2=-0.249072),
@@ -60,6 +61,7 @@
         'NB0656': Colorterm(primary="r", secondary="i", c0=0.037014, c1=-0.538947, c2=0.052489),
         'NB0718': Colorterm(primary="r", secondary="i", c0=-0.014742, c1=-0.787571, c2=0.237867),
         'NB0816': Colorterm(primary="i", secondary="z", c0=0.012676, c1=-0.660317, c2=0.055566),
+        'NB0872': Colorterm(primary="z", secondary="i",c0=-0.013552, c1=-0.041955, c2=0.002660),
         'NB0921': Colorterm(primary="z", secondary="i", c0=0.004619, c1=0.093019, c2=-0.126377),
         'NB0926': Colorterm(primary="z", secondary="i", c0=0.009369, c1=0.130261, c2=-0.119282),
         'NB0973': Colorterm(primary="z", secondary="i", c0=-0.005805, c1=0.220412, c2=-0.249072),
@@ -89,6 +91,7 @@
         'N656': Colorterm(primary="r", secondary="i", c0=0.035655, c1=-0.512046, c2=0.042796),
         'N718': Colorterm(primary="i", secondary="r", c0=-0.016294, c1=-0.233139, c2=0.252505),
         'N816': Colorterm(primary="i", secondary="z", c0=0.013806, c1=-0.717681, c2=0.049289),
+        'N872': Colorterm(primary="z", secondary="y",c0=-0.012544, c1=-0.106026, c2=-0.227728),
         'N921': Colorterm(primary="z", secondary="y", c0=0.002039, c1=-0.477412, c2=-0.492151),
         'N926': Colorterm(primary="z", secondary="y", c0=0.005230, c1=-0.574448, c2=-0.330899),
         'N973': Colorterm(primary="y", secondary="z", c0=-0.007775, c1=-0.050972, c2=-0.197278),
@@ -117,6 +120,7 @@
         'NB0656': Colorterm(primary="r", secondary="i", c0=0.035655, c1=-0.512046, c2=0.042796),
         'NB0718': Colorterm(primary="i", secondary="r", c0=-0.016294, c1=-0.233139, c2=0.252505),
         'NB0816': Colorterm(primary="i", secondary="z", c0=0.013806, c1=-0.717681, c2=0.049289),
+        'NB0872': Colorterm(primary="z", secondary="y",c0=-0.012544, c1=-0.106026, c2=-0.227728),
         'NB0921': Colorterm(primary="z", secondary="y", c0=0.002039, c1=-0.477412, c2=-0.492151),
         'NB0926': Colorterm(primary="z", secondary="y", c0=0.005230, c1=-0.574448, c2=-0.330899),
         'NB0973': Colorterm(primary="y", secondary="z", c0=-0.007775, c1=-0.050972, c2=-0.197278),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py	2023-07-31 09:41:09.621539512 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/extinctionCoeffs.py	2023-07-31 09:41:23.960691542 +0900
@@ -22,9 +22,10 @@
     "NB0656": 2.077,
     "NB0718": 1.812,
     "NB0816": 1.458,
+    "NB0872": 1.303,
     "NB0921": 1.187,
     "NB0926": 1.177,
-    "NB0973": 1.083
-    "IB0945": 1.134
-    "NB1010": 1.013
+    "NB0973": 1.083,
+    "IB0945": 1.134,
+    "NB1010": 1.013,
 }
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py	2023-07-31 09:41:09.624539544 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmBuildStars.py	2023-07-31 09:41:23.963691574 +0900
@@ -13,10 +13,10 @@
                     'N387': 'N387', 'N391': 'N391', 'N395': 'N395', 
                     'N400': 'N400', 'N430': 'N430', 'N468': 'N468', 
                     'N497': 'N497', 'N506': 'N506', 'N515': 'N515', 'N527': 'N527', 
-                    'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 
+                    'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 'N872': 'N872', 
                     'N921': 'N921', 'N926': 'N926', 'I945': 'I945', 
                     'N973': 'N973', 'N1010': 'N1010'}
-config.primaryBands = ('i', 'r', 'g', 'z', 'y', 'EBgri', 'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
+config.primaryBands = ('i', 'r', 'g', 'z', 'y', 'EBgri', 'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N872', 'N921', 'N926', 'I945', 'N973', 'N1010')
 config.doSubtractLocalBackground = True
 
 config.fgcmLoadReferenceCatalog.refObjLoader.ref_dataset_name = 'ps1_pv3_3pi_20170110'
@@ -26,7 +26,7 @@
                                                 'N387': 'g', 'N391': 'g', 'N395': 'g', 
                                                 'N400': 'g', 'N430': 'g', 'N468': 'g', 
                                                 'N497': 'g', 'N506': 'g', 'N515': 'g', 'N527': 'g', 
-                                                'N656': 'r', 'N718': 'i', 'N816': 'i', 
+                                                'N656': 'r', 'N718': 'i', 'N816': 'i', 'N872': 'z',
                                                 'N921': 'z', 'N926': 'z', 'I945': 'y', 
                                                 'N973': 'y', 'N1010': 'y'}
 config.fgcmLoadReferenceCatalog.applyColorTerms = True
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py	2023-07-31 09:41:09.626539565 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmCalibrateTract.py	2023-07-31 09:41:23.966691605 +0900
@@ -33,6 +33,7 @@
                                                           'N718': True,
                                                           'i': True,
                                                           'N816': True,
+                                                          'N872': True,
                                                           'z': True,
                                                           'N921': True,
                                                           'N926': True,
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py	2023-07-31 09:41:09.629539597 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmFitCycle.py	2023-07-31 09:45:53.619550571 +0900
@@ -6,17 +6,17 @@
 
 config.outfileBase = 'fgcmHscCalibrations'
 config.bands = ['N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'g', 
-                'N497', 'N506', 'N515', 'N527', 'N656', 'EBgri', 'r', 'N718', 'i', 'N816', 
+                'N497', 'N506', 'N515', 'N527', 'N656', 'EBgri', 'r', 'N718', 'i', 'N816', 'N872', 
                 'z', 'N921', 'N926', 'I945', 'y', 'N973', 'N1010']
 config.fitBands = ['N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'g', 
-                   'N497', 'N506', 'N515', 'N527', 'N656', 'EBgri','r', 'N718', 'i', 'N816', 
+                   'N497', 'N506', 'N515', 'N527', 'N656', 'EBgri','r', 'N718', 'i', 'N816', 'N872',
                    'z', 'N921', 'N926', 'I945', 'y', 'N973', 'N1010']
 config.filterMap = {'g': 'g', 'r': 'r', 'r2': 'r', 'i': 'i', 'i2': 'i',
                     'z': 'z', 'y': 'y', 'EBgri': 'EBgri',
                     'N387': 'N387', 'N391': 'N391', 'N395': 'N395', 
                     'N400': 'N400', 'N430': 'N430', 'N468': 'N468', 
                     'N497': 'N497', 'N506': 'N506', 'N515': 'N515', 'N527': 'N527', 
-                    'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 
+                    'N656': 'N656', 'N718': 'N718', 'N816': 'N816', 'N872': 'N872',
                     'N921': 'N921', 'N926': 'N926', 'I945': 'I945', 
                     'N973': 'N973', 'N1010': 'N1010'}
 config.maxIterBeforeFinalCycle = 75
@@ -44,6 +44,7 @@
                                     'N718': -0.05,
                                     'i': -0.05,
                                     'N816': -0.05,
+                                    'N872': -0.05,
                                     'z': -0.05,
                                     'N921': -0.05,
                                     'N926': -0.05,
@@ -68,6 +69,7 @@
                              'N718': 0.2,
                              'i': 0.2,
                              'N816': 0.2,
+                             'N872': 0.2,
                              'z': 0.2,
                              'N921': 0.2,
                              'N926': 0.2,
@@ -93,6 +95,7 @@
                                  'N718': -1.0,
                                  'i': -1.1436,
                                  'N816': -1.8149,
+                                 'N872': -1.0,
                                  'z': -1.6974,
                                  'N921': -1.3310,
                                  'N926': -1.0,
@@ -124,6 +127,7 @@
                               'N718': False,
                               'i': True,
                               'N816': True,
+                              'N872': False,
                               'z': True,
                               'N921': True,
                               'N926': False,
@@ -149,6 +153,7 @@
                             'N718': False,
                             'i': True,
                             'N816': True,
+                            'N872': False,
                             'z': True,
                             'N921': True,
                             'N926': False,
@@ -175,6 +180,7 @@
                                        'N718': 0.05,
                                        'i': 0.0025,
                                        'N816': 0.05,
+                                       'N872': 0.05,
                                        'z': 0.0025,
                                        'N921': 0.05,
                                        'N926': 0.05,
@@ -200,6 +206,7 @@
                                              'N718': True,
                                              'i': False,
                                              'N816': True,
+                                             'N872': True,
                                              'z': False,
                                              'N921': True,
                                              'N926': True,
@@ -224,6 +231,7 @@
                               'N718': 0.15,
                               'i': 0.05,
                               'N816': 0.15,
+                              'N872': 0.15,
                               'z': 0.05,
                               'N921': 0.15,
                               'N926': 0.15,
@@ -248,10 +256,11 @@
                                'N718': 1.0,
                                'i': 1.0,
                                'N816': 1.0,
+                               'N872': 1.0,
                                'z': 1.0,
                                'N921': 1.0,
                                'N926': 1.0,
-                               'I9945': 1.0,
+                               'I945': 1.0,
                                'y': 1.0,
                                'N973': 1.0,
                                'N1010': 1.0}
@@ -275,6 +284,7 @@
                                 'N656i': Sedboundaryterm(primary='N656', secondary='i'),
                                 'N718i': Sedboundaryterm(primary='N718', secondary='i'),
                                 'N816i': Sedboundaryterm(primary='N816', secondary='i'),
+                                'N872z': Sedboundaryterm(primary='N872', secondary='z'),
                                 'N921z': Sedboundaryterm(primary='N921', secondary='z'),
                                 'N926z': Sedboundaryterm(primary='N926', secondary='z'),
                                 'I945z': Sedboundaryterm(primary='I945', secondary='z'),
@@ -301,6 +311,7 @@
                         'N656': Sedterm(primaryTerm='N656i', constant=0.7),
                         'N718': Sedterm(primaryTerm='N718i', constant=1.0),
                         'N816': Sedterm(primaryTerm='N816i', constant=0.7),
+                        'N872': Sedterm(primaryTerm='N872z', constant=1.0),
                         'N921': Sedterm(primaryTerm='N921z', constant=0.5),
                         'N926': Sedterm(primaryTerm='N926z', constant=1.0),
                         'I945': Sedterm(primaryTerm='I945z', constant=1.0),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py	2023-07-31 09:41:09.632539629 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/fgcmMakeLut.py	2023-07-31 09:41:23.971691658 +0900
@@ -4,13 +4,13 @@
 
 # Filter names to build LUT ('short' names)
 config.filterNames = ('g', 'r', 'r2', 'i', 'i2', 'z', 'y', 'EBgri',
-                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
+                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N872', 'N921', 'N926', 'I945', 'N973', 'N1010')
 
 # Standard filterNames ('short' names)
 # These settings will put both "r" and "r2" filters on the
 # "r2" standard, and similar for "i" and "i2".
 config.stdFilterNames = ('g', 'r2', 'r2', 'i2', 'i2', 'z', 'y', 'EBgri',
-                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N921', 'N926', 'I945', 'N973', 'N1010')
+                      'N387', 'N391', 'N395', 'N400', 'N430', 'N468', 'N497', 'N506', 'N515', 'N527', 'N656', 'N718', 'N816', 'N872', 'N921', 'N926', 'I945', 'N973', 'N1010')
 
 # FGCM name or filename of precomputed atmospheres
 config.atmosphereTableName = 'fgcm_atm_subaru3'
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-07-31 09:41:09.635539661 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/filterMap.py	2023-07-31 09:41:23.974691690 +0900
@@ -18,6 +18,7 @@
         ('N656', 'r'),
         ('N718', 'i'),
         ('N816', 'i'),
+        ('N872', 'z'),
         ('N921', 'z'),
         ('N926', 'z'),
         ('N973', 'y'),
@@ -50,6 +51,7 @@
         ('NB0656', 'r'),
         ('NB0718', 'i'),
         ('NB0816', 'i'),
+        ('NB0872', 'z'),
         ('NB0921', 'z'),
         ('NB0926', 'z'),
         ('NB0973', 'y'),
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py	2023-07-31 09:41:09.638539693 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddDetections.py	2023-07-31 09:41:23.977691722 +0900
@@ -1,2 +1,2 @@
 config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "EB-GRI", "NB0921", "NB0816",
-                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0506", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945" ]
+                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0506", "NB0527", "NB0656", "NB0718", "NB0872", "NB0926", "NB0973", "IB0945" ]
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py	2023-07-31 09:41:09.640539714 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/config/hsc/mergeCoaddMeasurements.py	2023-07-31 09:41:23.980691754 +0900
@@ -1,2 +1,2 @@
 config.priorityList = ["HSC-I2", "HSC-I", "HSC-R2", "HSC-R", "HSC-Z", "HSC-Y", "HSC-G", "EB-GRI", "NB0921", "NB0816",
-                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0506", "NB0527", "NB0656", "NB0718", "NB0926", "NB0973", "IB0945" ]
+                       "NB1010", "NB0387", "NB0515", "NB0391", "NB0395", "NB0400", "NB0430", "NB0468", "NB0497", "NB0506", "NB0527", "NB0656", "NB0718", "NB0872", "NB0926", "NB0973", "IB0945" ]
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB872.txt 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB872.txt
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB872.txt	1970-01-01 09:00:00.000000000 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/hsc/transmission/wHSC-NB872.txt	2023-07-31 09:41:23.983691786 +0900
@@ -0,0 +1,335 @@
+# wavelength[angstrom]  transmittance
+8003.4  0.0004
+8007.8  0.0004
+8012.3  0.0004
+8016.7  0.0005
+8021.1  0.0005
+8025.6  0.0005
+8030.0  0.0004
+8034.5  0.0004
+8038.9  0.0004
+8043.3  0.0004
+8047.8  0.0004
+8052.2  0.0004
+8056.7  0.0004
+8061.1  0.0004
+8065.6  0.0004
+8070.0  0.0004
+8074.4  0.0004
+8078.9  0.0004
+8083.3  0.0004
+8087.8  0.0005
+8092.2  0.0005
+8096.7  0.0004
+8101.1  0.0005
+8105.6  0.0004
+8110.0  0.0004
+8114.4  0.0005
+8118.9  0.0005
+8123.3  0.0004
+8127.8  0.0005
+8132.2  0.0005
+8136.7  0.0005
+8141.1  0.0006
+8145.6  0.0005
+8150.0  0.0005
+8154.5  0.0005
+8158.9  0.0005
+8163.4  0.0005
+8167.8  0.0005
+8172.3  0.0005
+8176.7  0.0005
+8181.2  0.0005
+8185.6  0.0005
+8190.1  0.0005
+8194.5  0.0005
+8199.0  0.0005
+8203.4  0.0005
+8207.9  0.0005
+8212.3  0.0005
+8216.8  0.0005
+8221.2  0.0004
+8225.7  0.0005
+8230.1  0.0005
+8234.6  0.0005
+8239.1  0.0004
+8243.5  0.0005
+8248.0  0.0004
+8252.4  0.0004
+8256.9  0.0004
+8261.3  0.0005
+8265.8  0.0005
+8270.2  0.0005
+8274.7  0.0005
+8279.2  0.0005
+8283.6  0.0005
+8288.1  0.0005
+8292.5  0.0005
+8297.0  0.0005
+8301.4  0.0005
+8305.9  0.0005
+8310.4  0.0005
+8314.8  0.0005
+8319.3  0.0005
+8323.7  0.0005
+8328.2  0.0005
+8332.7  0.0005
+8337.1  0.0005
+8341.6  0.0006
+8346.0  0.0006
+8350.5  0.0005
+8355.0  0.0005
+8359.4  0.0005
+8363.9  0.0005
+8368.4  0.0005
+8372.8  0.0005
+8377.3  0.0005
+8381.7  0.0005
+8386.2  0.0006
+8390.7  0.0006
+8395.1  0.0006
+8399.6  0.0006
+8404.1  0.0005
+8408.5  0.0005
+8413.0  0.0005
+8417.5  0.0006
+8421.9  0.0005
+8426.4  0.0005
+8430.9  0.0005
+8435.3  0.0005
+8439.8  0.0005
+8444.3  0.0005
+8448.7  0.0005
+8453.2  0.0005
+8457.7  0.0006
+8462.1  0.0006
+8466.6  0.0005
+8471.1  0.0006
+8475.5  0.0006
+8480.0  0.0006
+8484.5  0.0006
+8488.9  0.0005
+8493.4  0.0005
+8497.9  0.0006
+8502.4  0.0006
+8506.8  0.0006
+8511.3  0.0006
+8515.8  0.0006
+8520.2  0.0005
+8524.7  0.0005
+8529.2  0.0005
+8533.7  0.0005
+8538.1  0.0006
+8542.6  0.0006
+8547.1  0.0006
+8551.5  0.0006
+8556.0  0.0005
+8560.5  0.0005
+8565.0  0.0005
+8569.4  0.0006
+8573.9  0.0007
+8578.4  0.0007
+8582.9  0.0007
+8587.3  0.0007
+8591.8  0.0008
+8596.3  0.0010
+8600.8  0.0011
+8605.2  0.0013
+8609.7  0.0015
+8614.2  0.0017
+8618.7  0.0020
+8623.2  0.0024
+8627.6  0.0030
+8632.1  0.0037
+8636.6  0.0048
+8641.1  0.0067
+8645.5  0.0101
+8650.0  0.0162
+8654.5  0.0264
+8659.0  0.0417
+8663.5  0.0629
+8667.9  0.0900
+8672.4  0.1229
+8676.9  0.1614
+8681.4  0.2056
+8685.9  0.2570
+8690.3  0.3176
+8694.8  0.3902
+8699.3  0.4756
+8703.8  0.5718
+8708.3  0.6723
+8712.8  0.7665
+8717.2  0.8418
+8721.7  0.8889
+8726.2  0.9053
+8730.7  0.8959
+8735.2  0.8691
+8739.7  0.8322
+8744.1  0.7890
+8748.6  0.7397
+8753.1  0.6813
+8757.6  0.6096
+8762.1  0.5224
+8766.6  0.4224
+8771.1  0.3174
+8775.5  0.2195
+8780.0  0.1393
+8784.5  0.0817
+8789.0  0.0456
+8793.5  0.0260
+8798.0  0.0167
+8802.5  0.0123
+8806.9  0.0099
+8811.4  0.0081
+8815.9  0.0066
+8820.4  0.0055
+8824.9  0.0047
+8829.4  0.0041
+8833.9  0.0035
+8838.4  0.0030
+8842.9  0.0026
+8847.3  0.0024
+8851.8  0.0023
+8856.3  0.0019
+8860.8  0.0016
+8865.3  0.0014
+8869.8  0.0013
+8874.3  0.0013
+8878.8  0.0012
+8883.3  0.0012
+8887.8  0.0011
+8892.3  0.0010
+8896.7  0.0010
+8901.2  0.0009
+8905.7  0.0009
+8910.2  0.0009
+8914.7  0.0009
+8919.2  0.0009
+8923.7  0.0008
+8928.2  0.0008
+8932.7  0.0008
+8937.2  0.0008
+8941.7  0.0009
+8946.2  0.0009
+8950.7  0.0010
+8955.2  0.0011
+8959.7  0.0009
+8964.2  0.0009
+8968.7  0.0009
+8973.2  0.0009
+8977.6  0.0010
+8982.1  0.0011
+8986.6  0.0010
+8991.1  0.0009
+8995.6  0.0009
+9000.1  0.0009
+9004.6  0.0008
+9009.1  0.0009
+9013.6  0.0009
+9018.1  0.0009
+9022.6  0.0009
+9027.1  0.0008
+9031.6  0.0009
+9036.1  0.0009
+9040.6  0.0008
+9045.1  0.0008
+9049.6  0.0008
+9054.1  0.0008
+9058.6  0.0008
+9063.1  0.0008
+9067.6  0.0009
+9072.1  0.0008
+9076.6  0.0008
+9081.1  0.0008
+9085.6  0.0008
+9090.1  0.0007
+9094.6  0.0008
+9099.1  0.0009
+9103.6  0.0009
+9108.1  0.0008
+9112.6  0.0008
+9117.1  0.0009
+9121.6  0.0009
+9126.2  0.0009
+9130.7  0.0009
+9135.2  0.0009
+9139.7  0.0010
+9144.2  0.0009
+9148.7  0.0009
+9153.2  0.0009
+9157.7  0.0009
+9162.2  0.0009
+9166.7  0.0009
+9171.2  0.0009
+9175.7  0.0008
+9180.2  0.0009
+9184.7  0.0010
+9189.2  0.0010
+9193.7  0.0010
+9198.2  0.0010
+9202.7  0.0010
+9207.2  0.0010
+9211.8  0.0010
+9216.3  0.0010
+9220.8  0.0010
+9225.3  0.0010
+9229.8  0.0009
+9234.3  0.0009
+9238.8  0.0010
+9243.3  0.0009
+9247.8  0.0010
+9252.3  0.0011
+9256.8  0.0010
+9261.3  0.0010
+9265.9  0.0011
+9270.4  0.0010
+9274.9  0.0010
+9279.4  0.0009
+9283.9  0.0010
+9288.4  0.0011
+9292.9  0.0011
+9297.4  0.0011
+9301.9  0.0010
+9306.5  0.0010
+9311.0  0.0010
+9315.5  0.0010
+9320.0  0.0011
+9324.5  0.0010
+9329.0  0.0011
+9333.5  0.0012
+9338.0  0.0013
+9342.6  0.0013
+9347.1  0.0012
+9351.6  0.0012
+9356.1  0.0013
+9360.6  0.0013
+9365.1  0.0014
+9369.6  0.0014
+9374.1  0.0016
+9378.7  0.0017
+9383.2  0.0018
+9387.7  0.0018
+9392.2  0.0018
+9396.7  0.0020
+9401.2  0.0019
+9405.7  0.0020
+9410.3  0.0022
+9414.8  0.0020
+9419.3  0.0020
+9423.8  0.0024
+9428.3  0.0025
+9432.8  0.0023
+9437.4  0.0022
+9441.9  0.0023
+9446.4  0.0024
+9450.9  0.0023
+9455.4  0.0022
+9459.9  0.0022
+9464.5  0.0023
+9469.0  0.0021
+9473.5  0.0021
+9478.0  0.0021
+9482.5  0.0020
+9487.1  0.0021
+9491.6  0.0020
+9496.1  0.0020
diff -Nur 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py
--- 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py	2023-07-31 09:41:09.650539820 +0900
+++ 8.4/lsst_home/stack/current/Linux64/obs_subaru/8.4-hsc/python/lsst/obs/hsc/hscFilters.py	2023-07-31 09:41:23.985691807 +0900
@@ -60,6 +60,8 @@
                      abstract_filter='N656', lambdaEff=656),
     FilterDefinition(physical_filter="NB0816",
                      abstract_filter='N816', lambdaEff=816),
+    FilterDefinition(physical_filter="NB0872",
+                     abstract_filter='N872', lambdaEff=872),
     FilterDefinition(physical_filter="NB0921",
                      abstract_filter='N921', lambdaEff=921),
     FilterDefinition(physical_filter="NB1010",
__eof__
fi
